/**************************************************************************//**
 * @file     IOTKit_CM33.h
 * @brief    CMSIS Core Peripheral Access Layer Header File for
 *           IOTKit_CM33 Device (configured for IOTKit_CM33 with FPU)
 * @version  V1.0.0
 * @date     16. June 2017
 ******************************************************************************/
/* Copyright (c) 2015 - 2017 ARM LIMITED

   All rights reserved.
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:
   - Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
   - Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
   - Neither the name of ARM nor the names of its contributors may be used
     to endorse or promote products derived from this software without
     specific prior written permission.
   *
   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL COPYRIGHT HOLDERS AND CONTRIBUTORS BE
   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
   INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
   ---------------------------------------------------------------------------*/


#ifndef IOTKit_CM33_H
#define IOTKit_CM33_H

#ifdef __cplusplus
extern "C" {
#endif


/* -------------------------  Interrupt Number Definition  ------------------------ */

typedef enum IRQn
{
/* --------------------  Core_IoT Processor Exceptions Numbers  ------------------- */
  NonMaskableInt_IRQn           = -14,      /*  2 Non Maskable Interrupt */
  HardFault_IRQn                = -13,      /*  3 HardFault Interrupt */
  MemoryManagement_IRQn         = -12,      /*  4 Memory Management Interrupt */
  BusFault_IRQn                 = -11,      /*  5 Bus Fault Interrupt */
  UsageFault_IRQn               = -10,      /*  6 Usage Fault Interrupt */
  SecureFault_IRQn              =  -9,      /*  7 Secure Fault Interrupt */
  SVCall_IRQn                   =  -5,      /* 11 SV Call Interrupt */
  DebugMonitor_IRQn             =  -4,      /* 12 Debug Monitor Interrupt */
  PendSV_IRQn                   =  -2,      /* 14 Pend SV Interrupt */
  SysTick_IRQn                  =  -1,      /* 15 System Tick Interrupt */

/* ----------------------  Core_IoT Specific Interrupt Numbers  ------------------- */
  NONSEC_WATCHDOG_RESET_IRQn    =   0,      /* Non-Secure Watchdog Reset Interrupt */
  NONSEC_WATCHDOG_IRQn          =   1,      /* Non-Secure Watchdog Interrupt */
  S32K_TIMER_IRQn               =   2,      /* S32K Timer Interrupt */
  TIMER0_IRQn                   =   3,      /* TIMER 0 Interrupt */
  TIMER1_IRQn                   =   4,      /* TIMER 1 Interrupt */
  DUALTIMER_IRQn                =   5,      /* Dual Timer Interrupt */
  MPC_IRQn                      =   9,      /* MPC Combined (Secure) Interrupt */
  PPC_IRQn                      =   10,     /* PPC Combined (Secure) Interrupt */
  MSC_IRQn                      =   11,     /* MSC Combined (Secure) Interrput */
  BRIDGE_ERROR_IRQn             =   12,     /* Bridge Error Combined (Secure) Interrupt */

/* ----------------------  IOTKIT_IoT Specific Interrupt Numbers  ------------------ */
  UART0RX_IRQn                  =   32,     /* UART 0 Receive Interrupt */
  UART0TX_IRQn                  =   33,     /* UART 0 Transmit Interrupt */
  UART1RX_IRQn                  =   34,     /* UART 1 Receive Interrupt */
  UART1TX_IRQn                  =   35,     /* UART 1 Transmit Interrupt */
  UART2RX_IRQn                  =   36,     /* UART 2 Receive Interrupt */
  UART2TX_IRQn                  =   37,     /* UART 2 Transmit Interrupt */
  UART3RX_IRQn                  =   38,     /* UART 3 Receive Interrupt */
  UART3TX_IRQn                  =   39,     /* UART 3 Transmit Interrupt */
  UART4RX_IRQn                  =   40,     /* UART 4 Receive Interrupt */
  UART4TX_IRQn                  =   41,     /* UART 4 Transmit Interrupt */
  UART0_IRQn                    =   42,     /* UART 0 Combined Interrupt */
  UART1_IRQn                    =   43,     /* UART 1 Combined Interrupt */
  UART2_IRQn                    =   44,     /* UART 2 Combined Interrupt */
  UART3_IRQn                    =   45,     /* UART 3 Combined Interrupt */
  UART4_IRQn                    =   46,     /* UART 4 Combined Interrupt */
  UARTOVF_IRQn                  =   47,     /* UART Overflow (0, 1, 2, 3, 4 & 5) Interrupt */
  ETHERNET_IRQn                 =   48,     /* Ethernet Interrupt */
  I2S0_IRQn                     =   49,     /* FPGA Audio I2S Interrupt */
  TSC_IRQn                      =   50,     /* Touch Screen Interrupt */
  USB_IRQn                      =   51,     /* USB Interrupt */
  SPI0_IRQn                     =   52,     /* SPI ADC Interrupt */
  SPI1_IRQn                     =   53,     /* SPI (Shield 0) Interrupt */
  SPI2_IRQn                     =   54,     /* SPI (Shield 1) Interrupt */
  I2S1_IRQn                     =   55,     /* HDMI Audio I2S Interrupt */
  DMA0_ERROR_IRQn               =   56,     /* DMA #0 Error Interrupt */
  DMA0_TC_IRQn                  =   57,     /* DMA #0 Terminal Count Interrupt */
  DMA0_IRQn                     =   58,     /* DMA #0 Combined Interrupt */
  DMA1_ERROR_IRQn               =   59,     /* DMA #1 Error Interrupt */
  DMA1_TC_IRQn                  =   60,     /* DMA #1 Terminal Count Interrupt */
  DMA1_IRQn                     =   61,     /* DMA #1 Combined Interrupt */
  DMA2_ERROR_IRQn               =   62,     /* DMA #2 Error Interrupt */
  DMA2_TC_IRQn                  =   63,     /* DMA #2 Terminal Count Interrupt */
  DMA2_IRQn                     =   64,     /* DMA #2 Combined Interrupt */
  DMA3_ERROR_IRQn               =   65,     /* DMA #3 Error Interrupt */
  DMA3_TC_IRQn                  =   66,     /* DMA #3 Terminal Count Interrupt */
  DMA3_IRQn                     =   67,     /* DMA #3 Combined Interrupt */
  GPIO0_IRQn                    =   68,     /* GPIO 0 Combined Interrupt */
  GPIO1_IRQn                    =   69,     /* GPIO 1 Combined Interrupt */
  GPIO2_IRQn                    =   70,     /* GPIO 2 Combined Interrupt */
  GPIO3_IRQn                    =   71,     /* GPIO 3 Combined Interrupt */
  GPIO0_0_IRQn                  =   72,     /* GPIO 0 individual interrupt 0 */
  GPIO0_1_IRQn                  =   73,     /* GPIO 0 individual interrupt 1 */
  GPIO0_2_IRQn                  =   74,     /* GPIO 0 individual interrupt 2 */
  GPIO0_3_IRQn                  =   75,     /* GPIO 0 individual interrupt 3 */
  GPIO0_4_IRQn                  =   76,     /* GPIO 0 individual interrupt 4 */
  GPIO0_5_IRQn                  =   77,     /* GPIO 0 individual interrupt 5 */
  GPIO0_6_IRQn                  =   78,     /* GPIO 0 individual interrupt 6 */
  GPIO0_7_IRQn                  =   79,     /* GPIO 0 individual interrupt 7 */
  GPIO0_8_IRQn                  =   80,     /* GPIO 0 individual interrupt 8 */
  GPIO0_9_IRQn                  =   81,     /* GPIO 0 individual interrupt 9 */
  GPIO0_10_IRQn                 =   82,     /* GPIO 0 individual interrupt 10 */
  GPIO0_11_IRQn                 =   83,     /* GPIO 0 individual interrupt 11 */
  GPIO0_12_IRQn                 =   84,     /* GPIO 0 individual interrupt 12 */
  GPIO0_13_IRQn                 =   85,     /* GPIO 0 individual interrupt 13 */
  GPIO0_14_IRQn                 =   86,     /* GPIO 0 individual interrupt 14 */
  GPIO0_15_IRQn                 =   87,     /* GPIO 0 individual interrupt 15 */
  GPIO1_0_IRQn                  =   88,     /* GPIO 1 individual interrupt 0 */
  GPIO1_1_IRQn                  =   89,     /* GPIO 1 individual interrupt 1 */
  GPIO1_2_IRQn                  =   90,     /* GPIO 1 individual interrupt 2 */
  GPIO1_3_IRQn                  =   91,     /* GPIO 1 individual interrupt 3 */
  GPIO1_4_IRQn                  =   92,     /* GPIO 1 individual interrupt 4 */
  GPIO1_5_IRQn                  =   93,     /* GPIO 1 individual interrupt 5 */
  GPIO1_6_IRQn                  =   94,     /* GPIO 1 individual interrupt 6 */
  GPIO1_7_IRQn                  =   95,     /* GPIO 1 individual interrupt 7 */
  GPIO1_8_IRQn                  =   96,     /* GPIO 1 individual interrupt 8 */
  GPIO1_9_IRQn                  =   97,     /* GPIO 1 individual interrupt 9 */
  GPIO1_10_IRQn                 =   98,     /* GPIO 1 individual interrupt 10 */
  GPIO1_11_IRQn                 =   99,     /* GPIO 1 individual interrupt 11 */
  GPIO1_12_IRQn                 =  100,     /* GPIO 1 individual interrupt 12 */
  GPIO1_13_IRQn                 =  101,     /* GPIO 1 individual interrupt 13 */
  GPIO1_14_IRQn                 =  102,     /* GPIO 1 individual interrupt 14 */
  GPIO1_15_IRQn                 =  103,     /* GPIO 1 individual interrupt 15 */
  GPIO2_0_IRQn                  =  104,     /* GPIO 2 individual interrupt 0 */
  GPIO2_1_IRQn                  =  105,     /* GPIO 2 individual interrupt 1 */
  GPIO2_2_IRQn                  =  106,     /* GPIO 2 individual interrupt 2 */
  GPIO2_3_IRQn                  =  107,     /* GPIO 2 individual interrupt 3 */
  GPIO2_4_IRQn                  =  108,     /* GPIO 2 individual interrupt 4 */
  GPIO2_5_IRQn                  =  109,     /* GPIO 2 individual interrupt 5 */
  GPIO2_6_IRQn                  =  110,     /* GPIO 2 individual interrupt 6 */
  GPIO2_7_IRQn                  =  111,     /* GPIO 2 individual interrupt 7 */
  GPIO2_8_IRQn                  =  112,     /* GPIO 2 individual interrupt 8 */
  GPIO2_9_IRQn                  =  113,     /* GPIO 2 individual interrupt 9 */
  GPIO2_10_IRQn                 =  114,     /* GPIO 2 individual interrupt 10 */
  GPIO2_11_IRQn                 =  115,     /* GPIO 2 individual interrupt 11 */
  GPIO2_12_IRQn                 =  116,     /* GPIO 2 individual interrupt 12 */
  GPIO2_13_IRQn                 =  117,     /* GPIO 2 individual interrupt 13 */
  GPIO2_14_IRQn                 =  118,     /* GPIO 2 individual interrupt 14 */
  GPIO2_15_IRQn                 =  119,     /* GPIO 2 individual interrupt 15 */
  GPIO3_0_IRQn                  =  120,     /* GPIO 3 individual interrupt 0 */
  GPIO3_1_IRQn                  =  121,     /* GPIO 3 individual interrupt 1 */
  GPIO3_2_IRQn                  =  122,     /* GPIO 3 individual interrupt 2 */
  GPIO3_3_IRQn                  =  123,     /* GPIO 3 individual interrupt 3 */
  UART5RX_IRQn                  =  124,     /* UART 5 Receive Interrupt */
  UART5TX_IRQn                  =  125,     /* UART 5 Transmit Interrupt */
  UART5_IRQn                    =  126      /* UART 5 Combined Interrupt */
} IRQn_Type;


/* ================================================================================ */
/* ================      Processor and Core Peripheral Section     ================ */
/* ================================================================================ */

/* -------  Start of section using anonymous unions and disabling warnings  ------- */
#if   defined (__CC_ARM)
  #pragma push
  #pragma anon_unions
#elif defined (__ICCARM__)
  #pragma language=extended
#elif defined(__ARMCC_VERSION) && (__ARMCC_VERSION >= 6010050)
  #pragma clang diagnostic push
  #pragma clang diagnostic ignored "-Wc11-extensions"
  #pragma clang diagnostic ignored "-Wreserved-id-macro"
#elif defined (__GNUC__)
  /* anonymous unions are enabled by default */
#elif defined (__TMS470__)
  /* anonymous unions are enabled by default */
#elif defined (__TASKING__)
  #pragma warning 586
#elif defined (__CSMC__)
  /* anonymous unions are enabled by default */
#else
  #warning Not supported compiler type
#endif


/* --------  Configuration of the IOTKIT_IoT Processor and Core Peripherals  ------- */
#define __CM33_REV            0x0002U       /* Core revision r0p1 */
#define __SAUREGION_PRESENT       1U        /* SAU regions are present */
#define __MPU_PRESENT             1U        /* MPU present */
#define __VTOR_PRESENT            1U        /* VTOR present */
#define __NVIC_PRIO_BITS          3U        /* Number of Bits used for Priority Levels */
#define __Vendor_SysTickConfig    0U        /* Set to 1 if different SysTick Config is used */
#define __FPU_PRESENT             1U        /* FPU present */
#define __DSP_PRESENT             1U        /* DSP extension present */

#include "core_cm33.h"                      /* Processor and core peripherals */
#include "system_IOTKit_CM33.h"             /* System Header */


/* ================================================================================ */
/* ================       Device Specific Peripheral Section       ================ */
/* ================================================================================ */

/*------------- Universal Asynchronous Receiver Transmitter (UART) -----------*/
typedef struct /* see "Cortex-M System Design Kit Technical Reference Manual r1p0" */
{
  __IOM  uint32_t  DATA;                     /* Offset: 0x000 (R/W) Data Register    */
  __IOM  uint32_t  STATE;                    /* Offset: 0x004 (R/W) Status Register  */
  __IOM  uint32_t  CTRL;                     /* Offset: 0x008 (R/W) Control Register */
  union {
    __IM   uint32_t  INTSTATUS;              /* Offset: 0x00C (R/ ) Interrupt Status Register */
    __OM   uint32_t  INTCLEAR;               /* Offset: 0x00C ( /W) Interrupt Clear Register  */
    };
  __IOM  uint32_t  BAUDDIV;                  /* Offset: 0x010 (R/W) Baudrate Divider Register */
} IOTKIT_UART_TypeDef;

/* IOTKIT_UART DATA Register Definitions */
#define IOTKIT_UART_DATA_DATA_Pos               0                                                    /* IOTKIT_UART DATA: DATA position */
#define IOTKIT_UART_DATA_DATA_Msk              (0xFFUL /*<< IOTKIT_UART_DATA_DATA_Pos*/)             /* IOTKIT_UART DATA: DATA mask */

/* IOTKIT_UART STATE Register Definitions */
#define IOTKIT_UART_STATE_RXBO_Pos              3                                                    /* IOTKIT_UART STATE: RX buffer overrun position */
#define IOTKIT_UART_STATE_RXBO_Msk             (0x1UL << IOTKIT_UART_STATE_RXOR_Pos)                 /* IOTKIT_UART STATE: RX buffer overrun mask */

#define IOTKIT_UART_STATE_TXBO_Pos              2                                                    /* IOTKIT_UART STATE: TX buffer overrun position */
#define IOTKIT_UART_STATE_TXBO_Msk             (0x1UL << IOTKIT_UART_STATE_TXOR_Pos)                 /* IOTKIT_UART STATE: TX buffer overrun mask */

#define IOTKIT_UART_STATE_RXBF_Pos              1                                                    /* IOTKIT_UART STATE: RX buffer full position */
#define IOTKIT_UART_STATE_RXBF_Msk             (0x1UL << IOTKIT_UART_STATE_RXBF_Pos)                 /* IOTKIT_UART STATE: RX buffer full mask */

#define IOTKIT_UART_STATE_TXBF_Pos              0                                                    /* IOTKIT_UART STATE: TX buffer full position */
#define IOTKIT_UART_STATE_TXBF_Msk             (0x1UL /*<< IOTKIT_UART_STATE_TXBF_Pos*/)             /* IOTKIT_UART STATE: TX buffer full mask */

/* IOTKIT_UART CTRL Register Definitions */
#define IOTKIT_UART_CTRL_HSTM_Pos               6                                                    /* IOTKIT_UART CTRL: HSTM position */
#define IOTKIT_UART_CTRL_HSTM_Msk              (0x01UL << IOTKIT_UART_CTRL_HSTM_Pos)                 /* IOTKIT_UART CTRL: HSTM mask */

#define IOTKIT_UART_CTRL_RXORINTEN_Pos          5                                                    /* IOTKIT_UART CTRL: RX overrun interrupt enable position */
#define IOTKIT_UART_CTRL_RXORINTEN_Msk         (0x01UL << IOTKIT_UART_CTRL_RXORINTEN_Pos)            /* IOTKIT_UART CTRL: RX overrun interrupt enable mask */

#define IOTKIT_UART_CTRL_TXORINTEN_Pos          4                                                    /* IOTKIT_UART CTRL: TX overrun interrupt enable position */
#define IOTKIT_UART_CTRL_TXORINTEN_Msk         (0x01UL << IOTKIT_UART_CTRL_TXORINTEN_Pos)            /* IOTKIT_UART CTRL: TX overrun interrupt enable mask */

#define IOTKIT_UART_CTRL_RXINTEN_Pos            3                                                    /* IOTKIT_UART CTRL: RX interrupt enable position */
#define IOTKIT_UART_CTRL_RXINTEN_Msk           (0x01UL << IOTKIT_UART_CTRL_RXINTEN_Pos)              /* IOTKIT_UART CTRL: RX interrupt enable mask */

#define IOTKIT_UART_CTRL_TXINTEN_Pos            2                                                    /* IOTKIT_UART CTRL: TX interrupt enable position */
#define IOTKIT_UART_CTRL_TXINTEN_Msk           (0x01UL << IOTKIT_UART_CTRL_TXINTEN_Pos)              /* IOTKIT_UART CTRL: TX interrupt enable mask */

#define IOTKIT_UART_CTRL_RXEN_Pos               1                                                    /* IOTKIT_UART CTRL: RXEN position */
#define IOTKIT_UART_CTRL_RXEN_Msk              (0x01UL << IOTKIT_UART_CTRL_RXEN_Pos)                 /* IOTKIT_UART CTRL: RXEN mask */

#define IOTKIT_UART_CTRL_TXEN_Pos               0                                                    /* IOTKIT_UART CTRL: TXEN position */
#define IOTKIT_UART_CTRL_TXEN_Msk              (0x01UL /*<< IOTKIT_UART_CTRL_TXEN_Pos*/)             /* IOTKIT_UART CTRL: TXEN mask */

/* IOTKIT_UART INTSTATUS Register Definitions */
#define IOTKIT_UART_INTSTATUS_RXORINT_Pos       3                                                    /* IOTKIT_UART INTSTATUS: RX overrun interrupt position */
#define IOTKIT_UART_INTSTATUS_RXORINT_Msk      (0x01UL << IOTKIT_UART_INTSTATUS_RXORINT_Pos)         /* IOTKIT_UART INTSTATUS: RX overrun interrupt mask */

#define IOTKIT_UART_INTSTATUS_TXORINT_Pos       2                                                    /* IOTKIT_UART INTSTATUS: TX overrun interrupt position */
#define IOTKIT_UART_INTSTATUS_TXORINT_Msk      (0x01UL << IOTKIT_UART_INTSTATUS_TXORINT_Pos)         /* IOTKIT_UART INTSTATUS: TX overrun interrupt mask */

#define IOTKIT_UART_INTSTATUS_RXINT_Pos         1                                                    /* IOTKIT_UART INTSTATUS: RX interrupt position */
#define IOTKIT_UART_INTSTATUS_RXINT_Msk        (0x01UL << IOTKIT_UART_INTSTATUS_RXINT_Pos)           /* IOTKIT_UART INTSTATUS: RX interrupt mask */

#define IOTKIT_INTSTATUS_TXINT_Pos              0                                                    /* IOTKIT_UART INTSTATUS: TX interrupt position */
#define IOTKIT_INTSTATUS_TXINT_Msk             (0x01UL /*<< IOTKIT_UART_INTSTATUS_TXINT_Pos*/)       /* IOTKIT_UART INTSTATUS: TX interrupt mask */

/* IOTKIT_UART INTCLEAR Register Definitions */
#define IOTKIT_UART_INTCLEAR_RXORINT_Pos        3                                                    /* IOTKIT_UART INTCLEAR: RX overrun interrupt position */
#define IOTKIT_UART_INTCLEAR_RXORINT_Msk       (0x01UL << IOTKIT_UART_INTCLEAR_RXORINT_Pos)          /* IOTKIT_UART INTCLEAR: RX overrun interrupt mask */

#define IOTKIT_UART_INTCLEAR_TXORINT_Pos        2                                                    /* IOTKIT_UART INTCLEAR: TX overrun interrupt position */
#define IOTKIT_UART_INTCLEAR_TXORINT_Msk       (0x01UL << IOTKIT_UART_INTCLEAR_TXORINT_Pos)          /* IOTKIT_UART INTCLEAR: TX overrun interrupt mask */

#define IOTKIT_UART_INTCLEAR_RXINT_Pos          1                                                    /* IOTKIT_UART INTCLEAR: RX interrupt position */
#define IOTKIT_UART_INTCLEAR_RXINT_Msk         (0x01UL << IOTKIT_UART_INTCLEAR_RXINT_Pos)            /* IOTKIT_UART INTCLEAR: RX interrupt mask */

#define IOTKIT_UART_INTCLEAR_TXINT_Pos          0                                                    /* IOTKIT_UART INTCLEAR: TX interrupt position */
#define IOTKIT_UART_INTCLEAR_TXINT_Msk         (0x01UL /*<< IOTKIT_UART_INTCLEAR_TXINT_Pos*/)        /* IOTKIT_UART INTCLEAR: TX interrupt mask */

/* IOTKIT_UART BAUDDIV Register Definitions */
#define IOTKIT_UART_BAUDDIV_Pos                 0                                                    /* IOTKIT_UART BAUDDIV: BAUDDIV position */
#define IOTKIT_UART_BAUDDIV_Msk                (0xFFFFFUL /*<< IOTKIT_UART_BAUDDIV_Pos*/)            /* IOTKIT_UART BAUDDIV: BAUDDIV mask */


/*--------------------- Timer (TIMER) ---------------------------------------*/
typedef struct /* see "Cortex-M System Design Kit Technical Reference Manual r1p0" */
{
  __IOM  uint32_t  CTRL;                     /* Offset: 0x000 (R/W) Control Register */
  __IOM  uint32_t  VALUE;                    /* Offset: 0x004 (R/W) Current Value Register */
  __IOM  uint32_t  RELOAD;                   /* Offset: 0x008 (R/W) Reload Value Register */
  union {
    __IM   uint32_t  INTSTATUS;              /* Offset: 0x00C (R/ ) Interrupt Status Register */
    __OM   uint32_t  INTCLEAR;               /* Offset: 0x00C ( /W) Interrupt Clear Register */
    };
} IOTKIT_TIMER_TypeDef;

/* IOTKIT_TIMER CTRL Register Definitions */
#define IOTKIT_TIMER_CTRL_INTEN_Pos             3                                                    /* IOTKIT_TIMER CTRL: interrupt enable position */
#define IOTKIT_TIMER_CTRL_INTEN_Msk            (0x01UL << IOTKIT_TIMER_CTRL_INTEN_Pos)               /* IOTKIT_TIMER CTRL: interrupt enable mask */

#define IOTKIT_TIMER_CTRL_SELEXTCLK_Pos         2                                                    /* IOTKIT_TIMER CTRL: Select external input as clock position */
#define IOTKIT_TIMER_CTRL_SELEXTCLK_Msk        (0x01UL << IOTKIT_TIMER_CTRL_SELEXTCLK_Pos)           /* IOTKIT_TIMER CTRL: Select external input as clock mask */

#define IOTKIT_TIMER_CTRL_SELEXTEN_Pos          1                                                    /* IOTKIT_TIMER CTRL: Select external input as enable position */
#define IOTKIT_TIMER_CTRL_SELEXTEN_Msk         (0x01UL << IOTKIT_TIMER_CTRL_SELEXTEN_Pos)            /* IOTKIT_TIMER CTRL: Select external input as enable mask */

#define IOTKIT_TIMER_CTRL_EN_Pos                0                                                    /* IOTKIT_TIMER CTRL: enable position */
#define IOTKIT_TIMER_CTRL_EN_Msk               (0x01UL /*<< IOTKIT_TIMER_CTRL_EN_Pos*/)              /* IOTKIT_TIMER CTRL: enable mask */

/* IOTKIT_TIMER VAL Register Definitions */
#define IOTKIT_TIMER_VAL_CURRENT_Pos            0                                                    /* IOTKIT_TIMER VALUE: current value position */
#define IOTKIT_TIMER_VAL_CURRENT_Msk           (0xFFFFFFFFUL /*<< IOTKIT_TIMER_VAL_CURRENT_Pos*/)    /* IOTKIT_TIMER VALUE: current value mask */

/* IOTKIT_TIMER RELOAD Register Definitions */
#define IOTKIT_TIMER_RELOAD_VAL_Pos             0                                                    /* IOTKIT_TIMER RELOAD: reload value position */
#define IOTKIT_TIMER_RELOAD_VAL_Msk            (0xFFFFFFFFUL /*<< IOTKIT_TIMER_RELOAD_VAL_Pos*/)     /* IOTKIT_TIMER RELOAD: reload value mask */

/* IOTKIT_TIMER INTSTATUS Register Definitions */
#define IOTKIT_TIMER_INTSTATUS_Pos              0                                                    /* IOTKIT_TIMER INTSTATUS: interrupt status position */
#define IOTKIT_TIMER_INTSTATUS_Msk             (0x01UL /*<< IOTKIT_TIMER_INTSTATUS_Pos*/)            /* IOTKIT_TIMER INTSTATUS: interrupt status mask */

/* IOTKIT_TIMER INTCLEAR Register Definitions */
#define IOTKIT_TIMER_INTCLEAR_Pos               0                                                    /* IOTKIT_TIMER INTCLEAR: interrupt clear position */
#define IOTKIT_TIMER_INTCLEAR_Msk              (0x01UL /*<< IOTKIT_TIMER_INTCLEAR_Pos*/)             /* IOTKIT_TIMER INTCLEAR: interrupt clear mask */


/*-------------------- Dual Timer (DUALTIMER) -------------------------------------------*/
typedef struct /* see "Cortex-M System Design Kit Technical Reference Manual r1p0" */
{
  __IOM uint32_t TIMER1LOAD;                 /* Offset: 0x000 (R/W) Timer 1 Load */
  __IM  uint32_t TIMER1VALUE;                /* Offset: 0x004 (R/ ) Timer 1 Counter Current Value */
  __IOM uint32_t TIMER1CONTROL;              /* Offset: 0x008 (R/W) Timer 1 Control */
  __OM  uint32_t TIMER1INTCLR;               /* Offset: 0x00C ( /W) Timer 1 Interrupt Clear */
  __IM  uint32_t TIMER1RIS;                  /* Offset: 0x010 (R/ ) Timer 1 Raw Interrupt Status */
  __IM  uint32_t TIMER1MIS;                  /* Offset: 0x014 (R/ ) Timer 1 masked Interrupt Status */
  __IOM uint32_t TIMER1BGLOAD;               /* Offset: 0x018 (R/W) Background Load Register */
        uint32_t RESERVED0;
  __IOM uint32_t TIMER2LOAD;                 /* Offset: 0x020 (R/W) Timer 2 Load */
  __IM  uint32_t TIMER2VALUE;                /* Offset: 0x024 (R/ ) Timer 2 Counter Current Value */
  __IOM uint32_t TIMER2CTRL;                 /* Offset: 0x028 (R/W) Timer 2 Control */
  __OM  uint32_t TIMER2INTCLR;               /* Offset: 0x02C ( /W) Timer 2 Interrupt Clear */
  __IM  uint32_t TIMER2RIS;                  /* Offset: 0x030 (R/ ) Timer 2 Raw Interrupt Status */
  __IM  uint32_t TIMER2MIS;                  /* Offset: 0x034 (R/ ) Timer 2 masked Interrupt Status */
  __IOM uint32_t TIMER2BGLOAD;               /* Offset: 0x038 (R/W) Background Load Register */
        uint32_t RESERVED1[945];
  __IOM uint32_t TIMERITCR;                  /* Offset: 0xF00 (R/W) Integration Test Control Register */
  __OM  uint32_t TIMERITOP;                  /* Offset: 0xF04 ( /W) Integration Test Output Set Register */
} IOTKIT_DUALTIMER_TypeDef;


typedef struct /* see "Cortex-M System Design Kit Technical Reference Manual r1p0" */
{
  __IOM uint32_t LOAD;                       /* Offset: 0x000 (R/W) Timer Load */
  __IM  uint32_t VALUE;                      /* Offset: 0x000 (R/W) Timer Counter Current Value */
  __IOM uint32_t CTRL;                       /* Offset: 0x000 (R/W) Timer Control */
  __OM  uint32_t INTCLR;                     /* Offset: 0x000 (R/W) Timer Interrupt Clear */
  __IM  uint32_t RIS;                        /* Offset: 0x000 (R/W) Timer Raw Interrupt Status */
  __IM  uint32_t MIS;                        /* Offset: 0x000 (R/W) Timer masked Interrupt Status */
  __IOM uint32_t BGLOAD;                     /* Offset: 0x000 (R/W) Background Load Register */
} IOTKIT_DUALTIMER_SINGLE_TypeDef;

/* IOTKIT_DUALTIMER LOAD Register Definitions */
#define IOTKIT_DUALTIMER_LOAD_Pos               0                                                    /* IOTKIT_DUALTIMER LOAD: LOAD position */
#define IOTKIT_DUALTIMER_LOAD_Msk              (0xFFFFFFFFUL /*<< IOTKIT_DUALTIMER_LOAD_Pos*/)       /* IOTKIT_DUALTIMER LOAD: LOAD mask */

/* IOTKIT_DUALTIMER VALUE Register Definitions */
#define IOTKIT_DUALTIMER_VALUE_Pos              0                                                    /* IOTKIT_DUALTIMER VALUE: VALUE position */
#define IOTKIT_DUALTIMER_VALUE_Msk             (0xFFFFFFFFUL /*<< IOTKIT_DUALTIMER_VALUE_Pos*/)      /* IOTKIT_DUALTIMER VALUE: VALUE mask */

/* IOTKIT_DUALTIMER CONTROL Register Definitions */
#define IOTKIT_DUALTIMER_CONTROL_EN_Pos         7                                                    /* IOTKIT_DUALTIMER CONTROL_EN: CONTROL Enable position */
#define IOTKIT_DUALTIMER_CONTROL_EN_Msk        (0x1UL << IOTKIT_DUALTIMER_CTRL_EN_Pos)               /* IOTKIT_DUALTIMER CONTROL_EN: CONTROL Enable mask */

#define IOTKIT_DUALTIMER_CONTROL_MODE_Pos       6                                                    /* IOTKIT_DUALTIMER CONTROL_MODE: CONTROL MODE position */
#define IOTKIT_DUALTIMER_CONTROL_MODE_Msk      (0x1UL << IOTKIT_DUALTIMER_CTRL_MODE_Pos)             /* IOTKIT_DUALTIMER CONTROL_MODE: CONTROL MODE mask */

#define IOTKIT_DUALTIMER_CONTROL_INTEN_Pos      5                                                    /* IOTKIT_DUALTIMER CONTROL_INTEN: CONTROL Int Enable position */
#define IOTKIT_DUALTIMER_CONTROL_INTEN_Msk     (0x1UL << IOTKIT_DUALTIMER_CTRL_INTEN_Pos)            /* IOTKIT_DUALTIMER CONTROL_INTEN: CONTROL Int Enable mask */

#define IOTKIT_DUALTIMER_CONTROL_PRE_Pos        2                                                    /* IOTKIT_DUALTIMER CONTROL.PRE: CONTROL TimerPre position */
#define IOTKIT_DUALTIMER_CONTROL_PRE_Msk       (0x3UL << IOTKIT_DUALTIMER_CTRL_PRE_Pos)              /* IOTKIT_DUALTIMER CONTROL.PRE: CONTROL TimerPre mask */

#define IOTKIT_DUALTIMER_CONTROL_SIZE_Pos       1                                                    /* IOTKIT_DUALTIMER CONTROL.SIZE: CONTROL SIZE position */
#define IOTKIT_DUALTIMER_CONTROL_SIZE_Msk      (0x1UL << IOTKIT_DUALTIMER_CTRL_SIZE_Pos)             /* IOTKIT_DUALTIMER CONTROL.SIZE: CONTROL SIZE mask */

#define IOTKIT_DUALTIMER_CONTROL_ONESHOT_Pos    0                                                    /* IOTKIT_DUALTIMER CONTROL.ONESHOT: CONTROL ONESHOOT position */
#define IOTKIT_DUALTIMER_CONTROL_ONESHOT_Msk   (0x1UL /*<< IOTKIT_DUALTIMER_CONTROL_ONESHOT_Pos*/)   /* IOTKIT_DUALTIMER CONTROL.ONESHOT: CONTROL ONESHOOT mask */

/* IOTKIT_DUALTIMER INTCLR Register Definitions */
#define IOTKIT_DUALTIMER_INTCLR_Pos             0                                                    /* IOTKIT_DUALTIMER INTCLR: INT Clear position */
#define IOTKIT_DUALTIMER_INTCLR_Msk            (0x1UL /*<< IOTKIT_DUALTIMER_INTCLR_Pos*/)            /* IOTKIT_DUALTIMER INTCLR: INT Clear  mask */

/* IOTKIT_DUALTIMER RIS Register Definitions */
#define IOTKIT_DUALTIMER_RIS_RINT_Pos           0                                                    /* IOTKIT_DUALTIMER RIS.RINT: Raw Int Status position */
#define IOTKIT_DUALTIMER_RIS_RINT_Msk          (0x1UL /*<< IOTKIT_DUALTIMER_RIS_RINT_Pos*/)          /* IOTKIT_DUALTIMER RIS.RINT: Raw Int Status mask */

/* IOTKIT_DUALTIMER MIS Register Definitions */
#define IOTKIT_DUALTIMER_MIS_INT_Pos            0                                                    /* IOTKIT_DUALTIMER MIS.INT: mask Int Status position */
#define IOTKIT_DUALTIMER_MIS_INT_Msk           (0x1UL /*<< IOTKIT_DUALTIMER_MIS_INT_Pos*/)           /* IOTKIT_DUALTIMER MIS.INT: mask Int Status mask */

/* IOTKIT_DUALTIMER BGLOAD Register Definitions */
#define IOTKIT_DUALTIMER_BGLOAD_Pos             0                                                    /* IOTKIT_DUALTIMER BGLOAD: Background Load position */
#define IOTKIT_DUALTIMER_BGLOAD_Msk            (0xFFFFFFFFUL /*<< IOTKIT_DUALTIMER_BGLOAD_Pos*/)     /* IOTKIT_DUALTIMER BGLOAD: Background Load mask */

/* IOTKIT_DUALTIMER TIMERITCR Register Definitions */
#define IOTKIT_DUALTIMER_TIMERITCR_ITMEN_Pos    0                                                    /* IOTKIT_DUALTIMER TIMERITCR.ITMEN: Integration Test Mode Enable position */
#define IOTKIT_DUALTIMER_TIMERITCR_ITMEN_Msk   (0x1UL /*<< IOTKIT_DUALTIMER_TIMERITCR_ITMEN_Pos*/)   /* IOTKIT_DUALTIMER TIMERITCR.ITMEN: Integration Test Mode Enable mask */

/* IOTKIT_DUALTIMER TIMERITOP Register Definitions */
#define IOTKIT_DUALTIMER_TIMERITOP_TIMINT2_Pos  1                                                    /* IOTKIT_DUALTIMER TIMERITOP.TIMINT2: Integration Test TIMINT2 value position */
#define IOTKIT_DUALTIMER_TIMERITOP_TIMINT2_Msk (0x1UL << IOTKIT_DUALTIMER_TIMERITOP_TIMINT2_Pos)     /* IOTKIT_DUALTIMER TIMERITOP.TIMINT2: Integration Test TIMINT2 value mask */

#define IOTKIT_DUALTIMER_TIMERITOP_TIMINT1_Pos  0                                                    /* IOTKIT_DUALTIMER TIMERITOP.TIMINT1: Integration Test TIMINT1 value position */
#define IOTKIT_DUALTIMER_TIMERITOP_TIMINT1_Msk (0x1UL /*<< IOTKIT_DUALTIMER_TIMERITOP_TIMINT1_Pos*/) /* IOTKIT_DUALTIMER TIMERITOP.TIMINT1: Integration Test TIMINT1 value mask */


/*------------------- Watchdog ----------------------------------------------*/
typedef struct /* see "Cortex-M System Design Kit Technical Reference Manual r1p0" */
{
  __IOM  uint32_t  LOAD;                    /* Offset: 0x000 (R/W) Load Register */
  __IOM  uint32_t  VALUE;                   /* Offset: 0x004 (R/ ) Value Register */
  __IOM  uint32_t  CONTROL;                 /* Offset: 0x008 (R/W) Control Register */
  __IOM  uint32_t  INTCLR;                  /* Offset: 0x00C ( /W) Clear Interrupt Register */
  __IOM  uint32_t  RIS;                     /* Offset: 0x010 (R/ ) Raw Interrupt Status Register */
  __IOM  uint32_t  MIS;                     /* Offset: 0x014 (R/ ) Interrupt Status Register */
         uint32_t  RESERVED0[762];
  __IOM  uint32_t  LOCK;                    /* Offset: 0xC00 (R/W) Lock Register */
         uint32_t  RESERVED1[191];
  __IOM  uint32_t  ITCR;                    /* Offset: 0xF00 (R/W) Integration Test Control Register */
  __IOM  uint32_t  ITOP;                    /* Offset: 0xF04 ( /W) Integration Test Output Set Register */
} IOTKIT_WATCHDOG_TypeDef;

/* IOTKIT_WATCHDOG LOAD Register Definitions */
#define IOTKIT_WATCHDOG_LOAD_Pos                0                                                    /* IOTKIT_WATCHDOG LOAD: LOAD position */
#define IOTKIT_WATCHDOG_LOAD_Msk               (0xFFFFFFFFUL /*<< IOTKIT_WATCHDOG_LOAD_Pos*/)        /* IOTKIT_WATCHDOG LOAD: LOAD mask */

/* IOTKIT_WATCHDOG VALUE Register Definitions */
#define IOTKIT_WATCHDOG_VALUE_Pos               0                                                    /* IOTKIT_WATCHDOG VALUE: VALUE position */
#define IOTKIT_WATCHDOG_VALUE_Msk              (0xFFFFFFFFUL /*<< IOTKIT_WATCHDOG_VALUE_Pos*/)       /* IOTKIT_WATCHDOG VALUE: VALUE mask */

/* IOTKIT_WATCHDOG CONTROL Register Definitions */
#define IOTKIT_WATCHDOG_CONTROL_RESEN_Pos       1                                                    /* IOTKIT_WATCHDOG CONTROL.RESEN: Reset Output Enable position */
#define IOTKIT_WATCHDOG_CONTROL_RESEN_Msk      (0x1UL << IOTKIT_WATCHDOG_CONTROL_RESEN_Pos)          /* IOTKIT_WATCHDOG CONTROL.RESEN: Reset Output Enable mask */

#define IOTKIT_WATCHDOG_CONTROL_INTEN_Pos       0                                                    /* IOTKIT_WATCHDOG CONTROL.INTEN: Int Enable position */
#define IOTKIT_WATCHDOG_CONTROL_INTEN_Msk      (0x1UL /*<< IOTKIT_WATCHDOG_CONTROL_INTEN_Pos*/)      /* IOTKIT_WATCHDOG CONTROL.INTEN: Int Enable mask */

/* IOTKIT_WATCHDOG INTCLR Register Definitions */
#define IOTKIT_WATCHDOG_INTCLR_Pos              0                                                    /* IOTKIT_WATCHDOG INTCLR: Interrutp clear position */
#define IOTKIT_WATCHDOG_INTCLR_Msk             (0x1UL /*<< IOTKIT_WATCHDOG_INTCLR_Pos*/)             /* IOTKIT_WATCHDOG INTCLR: Interrutp clear mask */

/* IOTKIT_WATCHDOG RIS Register Definitions */
#define IOTKIT_WATCHDOG_RIS_RINT_Pos            0                                                    /* IOTKIT_WATCHDOG RIS.RINT: Raw Watchdog Interrupt position */
#define IOTKIT_WATCHDOG_RIS_RINT_Msk           (0x1UL /*<< IOTKIT_WATCHDOG_RIS_RINT_Pos*/)           /* IOTKIT_WATCHDOG RIS.RINT: Raw Watchdog Interrupt mask */

/* IOTKIT_WATCHDOG MIS Register Definitions */
#define IOTKIT_WATCHDOG_MIS_INT_Pos             0                                                    /* IOTKIT_WATCHDOG MIS.INT: Watchdog Interrupt position */
#define IOTKIT_WATCHDOG_MIS_INT_Msk             (0x1UL /*<< IOTKIT_WATCHDOG_MIS_INT_Pos*/)           /* IOTKIT_WATCHDOG MIS.INT: Watchdog Interrupt mask */

/* IOTKIT_WATCHDOG LOCK Register Definitions */
#define IOTKIT_WATCHDOG_LOCK_WEN_Pos            0                                                    /* IOTKIT_WATCHDOG LOCK.WEN: Register write enable status position */
#define IOTKIT_WATCHDOG_LOCK_WEN_Msk           (0x1UL /*<< IOTKIT_WATCHDOG_LOCK_WEN_Pos*/)           /* IOTKIT_WATCHDOG LOCK.WEN: Register write enable status mask */

/* IOTKIT_WATCHDOG INTEGTESTEN Register Definitions */
#define IOTKIT_WATCHDOG_ITCR_ITMEN_Pos          0                                                    /* IOTKIT_WATCHDOG ITCR.ITMEN: Integration Test Mode Enable position */
#define IOTKIT_WATCHDOG_ITCR_ITMEN_Msk         (0x1UL /*<< IOTKIT_WATCHDOG_ITCR_ITMEN_Pos*/)         /* IOTKIT_WATCHDOG ITCR.ITMEN: Integration Test Mode Enable mask */

/* IOTKIT_WATCHDOG INTEGTESTOUTSET Register Definitions */
#define IOTKIT_WATCHDOG_ITOP_WDOGINT_Pos        1                                                    /* IOTKIT_WATCHDOG ITOP.WDOGINT: Integration Test WDOGINT value position */
#define IOTKIT_WATCHDOG_ITOP_WDOGINT_Msk       (0x1UL << IOTKIT_WATCHDOG_ITOP_WDOGINT_Pos)           /* IOTKIT_WATCHDOG ITOP.WDOGINT: Integration Test WDOGINT value mask */

#define IOTKIT_WATCHDOG_ITOP_WDOGRES_Pos        0                                                    /* IOTKIT_WATCHDOG ITOP.WDOGRES: Integration Test WDOGRES value position */
#define IOTKIT_WATCHDOG_ITOP_WDOGRES_Msk       (0x1UL /*<< IOTKIT_WATCHDOG_ITOP_WDOGRES_Pos*/)       /* IOTKIT_WATCHDOG ITOP.WDOGRES: Integration Test WDOGRES value mask */


/*-------------------- General Purpose Input Output (GPIO) -------------------*/
typedef struct /* see "Cortex-M System Design Kit Technical Reference Manual r1p0" */
{
  __IOM  uint32_t  DATA;                     /* Offset: 0x000 (R/W) DATA Register */
  __IOM  uint32_t  DATAOUT;                  /* Offset: 0x004 (R/W) Data Output Latch Register */
         uint32_t  RESERVED0[2];
  __IOM  uint32_t  OUTENSET;                 /* Offset: 0x010 (R/W) Output Enable Set Register */
  __IOM  uint32_t  OUTENCLR;                 /* Offset: 0x014 (R/W) Output Enable Clear Register */
  __IOM  uint32_t  ALTFUNCSET;               /* Offset: 0x018 (R/W) Alternate Function Set Register */
  __IOM  uint32_t  ALTFUNCCLR;               /* Offset: 0x01C (R/W) Alternate Function Clear Register */
  __IOM  uint32_t  INTENSET;                 /* Offset: 0x020 (R/W) Interrupt Enable Set Register */
  __IOM  uint32_t  INTENCLR;                 /* Offset: 0x024 (R/W) Interrupt Enable Clear Register */
  __IOM  uint32_t  INTTYPESET;               /* Offset: 0x028 (R/W) Interrupt Type Set Register */
  __IOM  uint32_t  INTTYPECLR;               /* Offset: 0x02C (R/W) Interrupt Type Clear Register */
  __IOM  uint32_t  INTPOLSET;                /* Offset: 0x030 (R/W) Interrupt Polarity Set Register */
  __IOM  uint32_t  INTPOLCLR;                /* Offset: 0x034 (R/W) Interrupt Polarity Clear Register */
  union {
    __IM   uint32_t  INTSTATUS;              /* Offset: 0x038 (R/ ) Interrupt Status Register */
    __OM   uint32_t  INTCLEAR;               /* Offset: 0x038 ( /W) Interrupt Clear Register */
  };
         uint32_t RESERVED1[241];
  __IOM  uint32_t LB_MASKED[256];            /* Offset: 0x400 (R/W) Lower byte masked Access Register */
  __IOM  uint32_t UB_MASKED[256];            /* Offset: 0x800 (R/W) Upper byte masked Access Register */
} IOTKIT_GPIO_TypeDef;

/* IOTKIT_GPIO DATA Register Definitions */
#define IOTKIT_GPIO_DATA_Pos                    0                                                    /* IOTKIT_GPIO DATA: DATA position */
#define IOTKIT_GPIO_DATA_Msk                   (0xFFFFUL /*<< IOTKIT_GPIO_DATA_Pos*/)                /* IOTKIT_GPIO DATA: DATA mask */

/* IOTKIT_GPIO DATAOUT Register Definitions */
#define IOTKIT_GPIO_DATAOUT_Pos                 0                                                    /* IOTKIT_GPIO DATAOUT: DATAOUT position */
#define IOTKIT_GPIO_DATAOUT_Msk                (0xFFFFUL /*<< IOTKIT_GPIO_DATAOUT_Pos*/)             /* IOTKIT_GPIO DATAOUT: DATAOUT mask */

/* IOTKIT_GPIO OUTENSET Register Definitions */
#define IOTKIT_GPIO_OUTENSET_Pos                0                                                    /* IOTKIT_GPIO OUTEN: OUTEN position */
#define IOTKIT_GPIO_OUTENSET_Msk               (0xFFFFUL /*<< IOTKIT_GPIO_OUTEN_Pos*/)               /* IOTKIT_GPIO OUTEN: OUTEN mask */

/* IOTKIT_GPIO OUTENCLR Register Definitions */
#define IOTKIT_GPIO_OUTENCLR_Pos                0                                                    /* IOTKIT_GPIO OUTEN: OUTEN position */
#define IOTKIT_GPIO_OUTENCLR_Msk               (0xFFFFUL /*<< IOTKIT_GPIO_OUTEN_Pos*/)               /* IOTKIT_GPIO OUTEN: OUTEN mask */

/* IOTKIT_GPIO ALTFUNCSET Register Definitions */
#define IOTKIT_GPIO_ALTFUNCSET_Pos              0                                                    /* IOTKIT_GPIO ALTFUNC: ALTFUNC position */
#define IOTKIT_GPIO_ALTFUNCSET_Msk             (0xFFFFUL /*<< IOTKIT_GPIO_ALTFUNC_Pos*/)             /* IOTKIT_GPIO ALTFUNC: ALTFUNC mask */

/* IOTKIT_GPIO ALTFUNCCLR Register Definitions */
#define IOTKIT_GPIO_ALTFUNCCLR_Pos              0                                                    /* IOTKIT_GPIO ALTFUNC: ALTFUNC position */
#define IOTKIT_GPIO_ALTFUNCCLR_Msk             (0xFFFFUL /*<< IOTKIT_GPIO_ALTFUNC_Pos*/)             /* IOTKIT_GPIO ALTFUNC: ALTFUNC mask */

/* IOTKIT_GPIO INTENSET Register Definitions */
#define IOTKIT_GPIO_INTENSET_Pos                0                                                    /* IOTKIT_GPIO INTEN: INTEN position */
#define IOTKIT_GPIO_INTENSET_Msk               (0xFFFFUL /*<< IOTKIT_GPIO_INTEN_Pos*/)               /* IOTKIT_GPIO INTEN: INTEN mask */

/* IOTKIT_GPIO INTENCLR Register Definitions */
#define IOTKIT_GPIO_INTENCLR_Pos                0                                                    /* IOTKIT_GPIO INTEN: INTEN position */
#define IOTKIT_GPIO_INTENCLR_Msk               (0xFFFFUL /*<< IOTKIT_GPIO_INTEN_Pos*/)               /* IOTKIT_GPIO INTEN: INTEN mask */

/* IOTKIT_GPIO INTTYPESET Register Definitions */
#define IOTKIT_GPIO_INTTYPESET_Pos              0                                                    /* IOTKIT_GPIO INTTYPE: INTTYPE position */
#define IOTKIT_GPIO_INTTYPESET_Msk             (0xFFFFUL /*<< IOTKIT_GPIO_INTTYPE_Pos*/)             /* IOTKIT_GPIO INTTYPE: INTTYPE mask */

/* IOTKIT_GPIO INTTYPECLR Register Definitions */
#define IOTKIT_GPIO_INTTYPECLR_Pos              0                                                    /* IOTKIT_GPIO INTTYPE: INTTYPE position */
#define IOTKIT_GPIO_INTTYPECLR_Msk             (0xFFFFUL /*<< IOTKIT_GPIO_INTTYPE_Pos*/)             /* IOTKIT_GPIO INTTYPE: INTTYPE mask */

/* IOTKIT_GPIO INTPOLSET Register Definitions */
#define IOTKIT_GPIO_INTPOLSET_Pos               0                                                    /* IOTKIT_GPIO INTPOL: INTPOL position */
#define IOTKIT_GPIO_INTPOLSET_Msk              (0xFFFFUL /*<< IOTKIT_GPIO_INTPOL_Pos*/)              /* IOTKIT_GPIO INTPOL: INTPOL mask */

/* IOTKIT_GPIO INTPOLCLR Register Definitions */
#define IOTKIT_GPIO_INTPOLCLR_Pos               0                                                    /* IOTKIT_GPIO INTPOL: INTPOL position */
#define IOTKIT_GPIO_INTPOLCLR_Msk              (0xFFFFUL /*<< IOTKIT_GPIO_INTPOL_Pos*/)              /* IOTKIT_GPIO INTPOL: INTPOL mask */

/* IOTKIT_GPIO INTCLEAR Register Definitions */
#define IOTKIT_GPIO_INTSTATUS_Pos               0                                                    /* IOTKIT_GPIO INTSTATUS: INTSTATUS position */
#define IOTKIT_GPIO_INTCLEAR_Msk               (0xFFUL /*<< IOTKIT_GPIO_INTSTATUS_Pos*/)             /* IOTKIT_GPIO INTSTATUS: INTSTATUS mask */

/* IOTKIT_GPIO INTCLEAR Register Definitions */
#define IOTKIT_GPIO_INTCLEAR_Pos                0                                                    /* IOTKIT_GPIO INTCLEAR: INTCLEAR position */
#define IOTKIT_GPIO_INTCLEAR_Msk               (0xFFUL /*<< IOTKIT_GPIO_INTCLEAR_Pos*/)              /* IOTKIT_GPIO INTCLEAR: INTCLEAR mask */

/* IOTKIT_GPIO maskLOWBYTE Register Definitions */
#define IOTKIT_GPIO_MASKLOWBYTE_Pos             0                                                    /* IOTKIT_GPIO maskLOWBYTE: maskLOWBYTE position */
#define IOTKIT_GPIO_MASKLOWBYTE_Msk            (0x00FFUL /*<< IOTKIT_GPIO_MASKLOWBYTE_Pos*/)         /* IOTKIT_GPIO maskLOWBYTE: maskLOWBYTE mask */

/* IOTKIT_GPIO maskHIGHBYTE Register Definitions */
#define IOTKIT_GPIO_MASKHIGHBYTE_Pos            0                                                    /* IOTKIT_GPIO maskHIGHBYTE: maskHIGHBYTE position */
#define IOTKIT_GPIO_MASKHIGHBYTE_Msk           (0xFF00UL /*<< IOTKIT_GPIO_MASKHIGHBYTE_Pos*/)        /* IOTKIT_GPIO maskHIGHBYTE: maskHIGHBYTE mask */


/*------------- System Control (SYSCON) --------------------------------------*/
typedef struct
{
  __IOM  uint32_t REMAP;                     /* Offset: 0x000 (R/W) Remap Control Register */
  __IOM  uint32_t PMUCTRL;                   /* Offset: 0x004 (R/W) PMU Control Register */
  __IOM  uint32_t RESETOP;                   /* Offset: 0x008 (R/W) Reset Option Register */
  __IOM  uint32_t EMICTRL;                   /* Offset: 0x00C (R/W) EMI Control Register */
  __IOM  uint32_t RSTINFO;                   /* Offset: 0x010 (R/W) Reset Information Register */
} IOTKIT_SYSCON_TypeDef;

/* IOTKIT_SYSCON REMAP Register Definitions */
#define IOTKIT_SYSCON_REMAP_Pos                 0
#define IOTKIT_SYSCON_REMAP_Msk                (0x1UL /*<< IOTKIT_SYSCON_REMAP_Pos*/)                /* IOTKIT_SYSCON MEME_CTRL: REMAP Mask */

/* IOTKIT_SYSCON PMUCTRL Register Definitions */
#define IOTKIT_SYSCON_PMUCTRL_EN_Pos            0
#define IOTKIT_SYSCON_PMUCTRL_EN_Msk           (0x1UL /*<< IOTKIT_SYSCON_PMUCTRL_EN_Pos*/)           /* IOTKIT_SYSCON PMUCTRL: PMUCTRL ENABLE Mask */

/* IOTKIT_SYSCON LOCKUPRST Register Definitions */
#define IOTKIT_SYSCON_LOCKUPRST_RESETOP_Pos     0
#define IOTKIT_SYSCON_LOCKUPRST_RESETOP_Msk    (0x1UL /*<< IOTKIT_SYSCON_LOCKUPRST_RESETOP_Pos*/)/* IOTKIT_SYSCON SYS_CTRL: LOCKUP RESET ENABLE Mask */

/* IOTKIT_SYSCON EMICTRL Register Definitions */
#define IOTKIT_SYSCON_EMICTRL_SIZE_Pos         24
#define IOTKIT_SYSCON_EMICTRL_SIZE_Msk         (0x1UL << IOTKIT_SYSCON_EMICTRL_SIZE_Pos)      /* IOTKIT_SYSCON EMICTRL: SIZE Mask */

#define IOTKIT_SYSCON_EMICTRL_TACYC_Pos        16
#define IOTKIT_SYSCON_EMICTRL_TACYC_Msk        (0x7UL << IOTKIT_SYSCON_EMICTRL_TACYC_Pos)     /* IOTKIT_SYSCON EMICTRL: TURNAROUNDCYCLE Mask */

#define IOTKIT_SYSCON_EMICTRL_WCYC_Pos          8
#define IOTKIT_SYSCON_EMICTRL_WCYC_Msk         (0x3UL << IOTKIT_SYSCON_EMICTRL_WCYC_Pos)      /* IOTKIT_SYSCON EMICTRL: WRITECYCLE Mask */

#define IOTKIT_SYSCON_EMICTRL_RCYC_Pos          0
#define IOTKIT_SYSCON_EMICTRL_RCYC_Msk         (0x7UL /*<< IOTKIT_SYSCON_EMICTRL_RCYC_Pos*/)  /* IOTKIT_SYSCON EMICTRL: READCYCLE Mask */

/* IOTKIT_SYSCON RSTINFO Register Definitions */
#define IOTKIT_SYSCON_RSTINFO_LOCKUPRESET_Pos   2
#define IOTKIT_SYSCON_RSTINFO_LOCKUPRESET_Msk  (0x1UL << IOTKIT_SYSCON_RSTINFO_LOCKUPRESET_Pos) /* IOTKIT_SYSCON RSTINFO: LOCKUPRESET Mask */

#define IOTKIT_SYSCON_RSTINFO_WDOGRESETREQ_Pos  1
#define IOTKIT_SYSCON_RSTINFO_WDOGRESETREQ_Msk (0x1UL << IOTKIT_SYSCON_RSTINFO_WDOGRESETREQ_Pos) /* IOTKIT_SYSCON RSTINFO: WDOGRESETREQ Mask */

#define IOTKIT_SYSCON_RSTINFO_SYSRESETREQ_Pos   0
#define IOTKIT_SYSCON_RSTINFO_SYSRESETREQ_Msk  (0x1UL /*<< IOTKIT_SYSCON_RSTINFO_SYSRESETREQ_Pos*/) /* IOTKIT_SYSCON RSTINFO: SYSRESETREQ Mask */


/*------------------- FPGA I/O ----------------------------------------------*/
typedef struct /* see "Application Note AN519 Example IoT Kit Subsystem design for V2M-MPS2" */
{
  __IOM  uint32_t LED;                       /* Offset: 0x000 (R/W)  LED connections */
         uint32_t RESERVED0[1];
  __IOM  uint32_t BUTTON;                    /* Offset: 0x008 (R/W)  Buttons */
         uint32_t RESERVED1[1];
  __IOM  uint32_t CLK1HZ;                    /* Offset: 0x010 (R/W)  1Hz up counter */
  __IOM  uint32_t CLK100HZ;                  /* Offset: 0x014 (R/W)  100Hz up counter */
  __IOM  uint32_t COUNTER;                   /* Offset: 0x018 (R/W)  Cycle Up Counter */
  __IOM  uint32_t PRESCALE;                  /* Offset: 0x01C (R/W)  Reload value for prescale counter */
  __IOM  uint32_t PSCNTR;                    /* Offset: 0x020 (R/W)  32-bit Prescale counter */
         uint32_t RESERVED3[1];
  __IOM  uint32_t SWITCHES;                  /* Offset: 0x028 (R/W)  Switches */
         uint32_t RESERVED4[8];
  __IOM  uint32_t MISC;                      /* Offset: 0x04C (R/W)  Miscellaneous control */
} IOTKIT_FPGAIO_TypeDef;

/* IOTKIT_FPGAIO_LED Register Definitions */
#define IOTKIT_FPGAIO_LED_LED_Pos               0                                                    /* IOTKIT_FPGAIO LED.LED: LED position */
#define IOTKIT_FPGAIO_LED_LED_Msk              (0x1FFUL /*<< IOTKIT_FPGAIO_LED_LED_Pos*/)            /* IOTKIT_FPGAIO LED.LED: LED mask */

/* IOTKIT_FPGAIO_BUTTON Register Definitions */
#define IOTKIT_FPGAIO_BUTTON_Buttons_Pos        0                                                    /* IOTKIT_FPGAIO BUTTON.Buttons: BUTTON position */
#define IOTKIT_FPGAIO_BUTTON_Buttons_Msk       (0x3UL /*<< IOTKIT_FPGACTRL_BUTTON_Buttons_Pos*/)     /* IOTKIT_FPGAIO BUTTON.Buttons: BUTTON mask */

/* IOTKIT_FPGAIO_SWITCHES Register Definitions */
#define IOTKIT_FPGAIO_SWITCHES_Switches_Pos     0                                                    /* IOTKIT_FPGAIO SWITCHES.Switches: SWITCHES position */
#define IOTKIT_FPGAIO_SWITCHES_Switches_Msk    (0x7UL /*<< IOTKIT_FPGACTRL_SWITCHES_Switches_Pos*/)  /* IOTKIT_FPGAIO SWITCHES.Switches: SWITCHES mask */

/* IOTKIT_FPGAIO_MISC Register Definitions */
#define IOTKIT_FPGAIO_MISC_SHIELD1SPInCS_Pos    9                                                    /* IOTKIT_FPGAIO MISC.SHIELD1SPInCS: SHIELD_1_SPI_nCS position */
#define IOTKIT_FPGAIO_MISC_SHIELD1SPInCS_Msk   (0x1UL << IOTKIT_FPGAIO_MISC_SHIELD1SPInCS_Pos)       /* IOTKIT_FPGAIO MISC.SHIELD1SPInCS: SHIELD_1_SPI_nCS mask */

#define IOTKIT_FPGAIO_MISC_SHIELD0SPInCS_Pos    8                                                    /* IOTKIT_FPGAIO MISC.SHIELD0SPInCS: SHIELD_0_SPI_nCS position */
#define IOTKIT_FPGAIO_MISC_SHIELD0SPInCS_Msk   (0x1UL << IOTKIT_FPGAIO_MISC_SHIELD0SPInCS_Pos)       /* IOTKIT_FPGAIO MISC.SHIELD0SPInCS: SHIELD_0_SPI_nCS mask */

#define IOTKIT_FPGAIO_MISC_ADCSPInCS_Pos        7                                                    /* IOTKIT_FPGAIO MISC.ADCSPInCS: ADC_SPI_nCS position */
#define IOTKIT_FPGAIO_MISC_ADCSPInCS_Msk       (0x1UL << IOTKIT_FPGAIO_MISC_ADCSPInCS_Pos)           /* IOTKIT_FPGAIO MISC.ADCSPInCS: ADC_SPI_nCS mask */


/*------------------- SCC ----------------------------------------------*/
typedef struct /* see "Application Note AN522 Example IoT Kit Subsystem design for V2M-MPS3" */
{
  __IOM uint32_t CFG_REG0;                   /* Offset: 0x000 (R/W)  Reserved */
  __IOM uint32_t CFG_REG1;                   /* Offset: 0x004 (R/W)  Reserved */
  __IOM uint32_t CFG_REG2;                   /* Offset: 0x004 (R/W)  Reserved */
  __IM  uint32_t CFG_REG3;                   /* Offset: 0x008 (R/ )  Reserved */
  __IM  uint32_t CFG_REG4;                   /* Offset: 0x00C (R/ )  Board Revision */
  __I   uint32_t CFG_ACLK;                   /* Offset: 0x014 (R/ )  System Clock */
        uint32_t RESERVED0[34];
  __IOM uint32_t SYS_CFGDATA_RTN;            /* Offset: 0x0A0 (R/W)  User data register */
  __IOM uint32_t SYS_CFGDATA_OUT;            /* Offset: 0x0A4 (R/W)  User data register */
  __IOM uint32_t SYS_CFGCTRL;                /* Offset: 0x0A8 (R/W)  Control register */
  __IOM uint32_t SYS_CFGSTAT;                /* Offset: 0x0AC (R/W)  Status register */
  __IOM uint32_t RESERVED1[20];
  __IOM uint32_t SCC_DLL;                    /* Offset: 0x100 (R/W)  DLL Lock Register */
        uint32_t RESERVED2[957];
  __IM  uint32_t SCC_AID;                    /* Offset: 0xFF8 (R/ )  SCC AID Register */
  __IM  uint32_t SCC_ID;                     /* Offset: 0xFFC (R/ )  Contains information about the FPGA image */
} IOTKIT_SCC_TypeDef;

/*
    CFG_REG0             [31:0] : Reserved
    CFG_REG1             [31:8] : Reserved
                          [7:0] : MCC LEDs (0 = OFF 1 = ON)
    CFG_REG2             [31:0] : Reserved
    CFG_REG3             [31:8] : Reserved
                          [7:0] : MCC switches (0 = OFF 1 = ON)
    CFG_REG4             [31:4] : Reserved
                          [3:0] : Board Revision
    SYS_CFGDATA_RTN      [31:0] : DATA [r/w]
    SYS_CFGDATA_OUT      [31:0] : DATA [r/w]
    SYS_CFGCTRL            [31] : Start (generates interrupt on write to this bit)
                           [30] : R/W access
                        [29:26] : Reserved
                        [25:20] : Function value
                        [19:12] : Reserved
                         [11:0] : Device (value of 0/1/2 for supported clocks)
    SYS_CFGSTAT             [0] : Complete
                            [1] : Error
    SCC_DLL             [31:24] : DLL LOCK MASK[7:0] - These bits indicate if the DLL locked is masked.
                        [23:16] : DLL LOCK MASK[7:0] - These bits indicate if the DLLs are locked or unlocked.
                         [15:1] : Reserved
                            [0] : This bit indicates if all enabled DLLs are locked:
    SCC_AID             [31:24] : FPGA build number
                        [23:20] : V2M-MPS3 target board revision (A = 0, B = 1, C = 2)
                         [19:8] : Reserved
                          [7:0] : number of SCC configuration register
    SCC_ID              [31:24] : Implementer ID: 0x41 = ARM
                        [23:20] : Reserved
                        [19:16] : IP Architecture: 0x4 = AHB
                         [11:4] : Primary part number: 522 = AN522
                          [3:0] : Reserved
 */



/*------------------- Audio I2S control ----------------------------------------------*/
typedef struct /* see "Application Note AN519 Example IoT Kit Subsystem design for V2M-MPS2" */
{
  __IOM  uint32_t CONTROL;                   /* Offset: 0x000 (R/W) CONTROL Register */
  __IM   uint32_t STATUS;                    /* Offset: 0x004 (R/ ) STATUS Register */
  union {
    __IM   uint32_t ERROR;                   /* Offset: 0x008 (R/ ) Error Status Register */
    __OM   uint32_t ERRORCLR;                /* Offset: 0x008 ( /W) Error Clear Register */
  };
  __IOM  uint32_t DIVIDE;                    /* Offset: 0x00C (R/W) Divide ratio Register */
  __OM   uint32_t TXBUF;                     /* Offset: 0x010 ( /W) Transmit Buffer */
  __IM   uint32_t RXBUF;                     /* Offset: 0x014 (R/ ) Receive Buffer */
         uint32_t RESERVED1[186];
  __IOM  uint32_t ITCR;                      /* Offset: 0x300 (R/W) Integration Test Control Register */
  __OM   uint32_t ITIP1;                     /* Offset: 0x304 ( /W) Integration Test Input Register 1 */
  __OM   uint32_t ITOP1;                     /* Offset: 0x308 ( /W) Integration Test Output Register 1 */
} IOTKIT_I2S_TypeDef;

/* IOTKIT_I2S_CONTROL Register Definitions */
#define IOTKIT_I2S_CONTROL_CODECRST_Pos        17                                                    /* IOTKIT_I2S CONTROL.CODECRST: Codec reset position */
#define IOTKIT_I2S_CONTROL_CODECRST_Msk        (1UL << IOTKIT_I2S_CONTROL_CODECRST_Pos)              /* IOTKIT_I2S CONTROL.CODECRST: Codec reset mask */

#define IOTKIT_I2S_CONTROL_FIFORST_Pos         16                                                    /* IOTKIT_I2S CONTROL.FIFORST: FIFO reset position */
#define IOTKIT_I2S_CONTROL_FIFORST_Msk         (1UL << IOTKIT_I2S_CONTROL_FIFORST_Pos)               /* IOTKIT_I2S CONTROL.FIFORST: FIFO reset mask */

#define IOTKIT_I2S_CONTROL_RXWLVL_Pos          12                                                    /* IOTKIT_I2S CONTROL.RXWLVL: RX Buffer IRQ Water Level position */
#define IOTKIT_I2S_CONTROL_RXWLVL_Msk          (7UL << IOTKIT_I2S_CONTROL_RXWLVL_Pos)                /* IOTKIT_I2S CONTROL.RXWLVL: RX Buffer IRQ Water Level mask */

#define IOTKIT_I2S_CONTROL_TXWLVL_Pos           8                                                    /* IOTKIT_I2S CONTROL.TXWLVL: TX Buffer IRQ Water Level position */
#define IOTKIT_I2S_CONTROL_TXWLVL_Msk          (7UL << IOTKIT_I2S_CONTROL_TXWLVL_Pos)                /* IOTKIT_I2S CONTROL.TXWLVL: TX Buffer IRQ Water Level mask */

#define IOTKIT_I2S_CONTROL_RXINTEN_Pos          3                                                    /* IOTKIT_I2S CONTROL.RXINTEN: RX interrupt enable position */
#define IOTKIT_I2S_CONTROL_RXINTEN_Msk         (1UL << IOTKIT_I2S_CONTROL_RXINTEN_Pos)               /* IOTKIT_I2S CONTROL.RXINTEN: RX interrupt enable mask */

#define IOTKIT_I2S_CONTROL_RXEN_Pos             2                                                    /* IOTKIT_I2S CONTROL.RXEN: RX enable position */
#define IOTKIT_I2S_CONTROL_RXEN_Msk            (1UL << IOTKIT_I2S_CONTROL_RXEN_Pos)                  /* IOTKIT_I2S CONTROL.RXEN: RX enable mask */

#define IOTKIT_I2S_CONTROL_TXINTEN_Pos          1                                                    /* IOTKIT_I2S CONTROL.TXINTEN: TX interrupt enable position */
#define IOTKIT_I2S_CONTROL_TXINTEN_Msk         (1UL << IOTKIT_I2S_CONTROL_TXINTEN_Pos)               /* IOTKIT_I2S CONTROL.TXINTEN: TX interrupt enable mask */

#define IOTKIT_I2S_CONTROL_TXEN_Pos             0                                                    /* IOTKIT_I2S CONTROL.TXEN: TX enable position */
#define IOTKIT_I2S_CONTROL_TXEN_Msk            (1UL /*<< IOTKIT_I2S_CONTROL_TXEN_Pos*/)              /* IOTKIT_I2S CONTROL.TXEN: TX enable mask */

/* IOTKIT_I2S_STATUS Register Definitions */
#define IOTKIT_I2S_STATUS_RXFULL_Pos            5                                                    /* IOTKIT_I2S STATUS.RXFULL: RX Buffer Full position */
#define IOTKIT_I2S_STATUS_RXFULL_Msk           (1UL << IOTKIT_I2S_STATUS_RXFULL_Pos)                 /* IOTKIT_I2S STATUS.RXFULL: RX Buffer Full mask */

#define IOTKIT_I2S_STATUS_RXEMPTY_Pos           4                                                    /* IOTKIT_I2S STATUS.RXEMPTY: RX Buffer Empty position */
#define IOTKIT_I2S_STATUS_RXEMPTY_Msk          (1UL << IOTKIT_I2S_STATUS_RXEMPTY_Pos)                /* IOTKIT_I2S STATUS.RXEMPTY: RX Buffer Empty mask */

#define IOTKIT_I2S_STATUS_TXFULL_Pos            3                                                    /* IOTKIT_I2S STATUS.TXFULL: TX Buffer Full position */
#define IOTKIT_I2S_STATUS_TXFULL_Msk           (1UL << IOTKIT_I2S_STATUS_TXFULL_Pos)                 /* IOTKIT_I2S STATUS.TXFULL: TX Buffer Full mask */

#define IOTKIT_I2S_STATUS_TXEMPTY_Pos           2                                                    /* IOTKIT_I2S STATUS.TXEMPTY: TX Buffer Empty position */
#define IOTKIT_I2S_STATUS_TXEMPTY_Msk          (1UL << IOTKIT_I2S_STATUS_TXEMPTY_Pos)                /* IOTKIT_I2S STATUS.TXEMPTY: TX Buffer Empty mask */

#define IOTKIT_I2S_STATUS_RXINT_Pos             1                                                    /* IOTKIT_I2S STATUS.RXINT: RX Buffer Alert position */
#define IOTKIT_I2S_STATUS_RXINT_Msk            (1UL << IOTKIT_I2S_STATUS_RXINT_Pos)                  /* IOTKIT_I2S STATUS.RXINT: RX Buffer Alert mask */

#define IOTKIT_I2S_STATUS_TXINT_Pos             0                                                    /* IOTKIT_I2S STATUS.TXINT: TX Buffer Alert position */
#define IOTKIT_I2S_STATUS_TXINT_Msk            (1UL /*<< IOTKIT_I2S_STATUS_TXINT_Pos*/)              /* IOTKIT_I2S STATUS.TXINT: TX Buffer Alert mask */

/* IOTKIT_I2S_ERROR Register Definitions */
#define IOTKIT_I2S_ERROR_RXERR_Pos              1                                                    /* IOTKIT_I2S ERROR.RXERR: RX overrun position */
#define IOTKIT_I2S_ERROR_RXERR_Msk             (1UL << IOTKIT_I2S_ERROR_RXERR_Pos)                   /* IOTKIT_I2S ERROR.RXERR: RX overrun mask */

#define IOTKIT_I2S_ERROR_TXERR_Pos              0                                                    /* IOTKIT_I2S ERROR.TXERR: TX overrun or underrun position */
#define IOTKIT_I2S_ERROR_TXERR_Msk             (1UL /*<< IOTKIT_I2S_ERROR_TXERR_Pos*/)               /* IOTKIT_I2S ERROR.TXERR: TX overrun or underrun mask */



/*------------------- I2C ----------------------------------------------*/
typedef struct /* see Document ? */
{
  union {
    __OM  uint32_t CONTROLS;                 /* Offset: 0x000 ( /W)  CONTROL Set Register */
    __IM  uint32_t CONTROL;                  /* Offset: 0x000 (R/ )  CONTROL Status Register */
  };
  __OM  uint32_t CONTROLC;                   /* Offset: 0x004 ( /W)  CONTROL Clear Register */
} IOTKIT_I2C_TypeDef;

/* IOTKIT_I2C_CONTROLS Register Definitions */
#define IOTKIT_I2C_CONTROLS_SDA_Pos            1                                                     /* IOTKIT_I2C CONTROLS.SDA: SDA position */
#define IOTKIT_I2C_CONTROLS_SDA_Msk           (1UL << IOTKIT_I2C_CONTROLS_SDA_Pos)                   /* IOTKIT_I2C CONTROLS.SDA: SDA mask */

#define IOTKIT_I2C_CONTROLS_SCL_Pos             0                                                    /* IOTKIT_I2C CONTROLS.SCL: SCL position */
#define IOTKIT_I2C_CONTROLS_SCL_Msk            (1UL /*<< IOTKIT_I2C_CONTROLS_SCL_Pos*/)              /* IOTKIT_I2C CONTROLS.SCL: SCL mask */

/* IOTKIT_I2C_CONTROL Register Definitions */
#define IOTKIT_I2C_CONTROL_SDA_Pos              1                                                    /* IOTKIT_I2C CONTROL.SDA: SDA position */
#define IOTKIT_I2C_CONTROL_SDA_Msk             (1UL << IOTKIT_I2C_CONTROL_SDA_Pos)                   /* IOTKIT_I2C CONTROL.SDA: SDA mask */

#define IOTKIT_I2C_CONTROL_SCL_Pos              0                                                    /* IOTKIT_I2C CONTROL.SCL: SCL position */
#define IOTKIT_I2C_CONTROL_SCL_Msk             (1UL /*<< IOTKIT_I2C_CONTROL_SCL_Pos*/)               /* IOTKIT_I2C CONTROL.SCL: SCL mask */

/* IOTKIT_I2C_CONTROLC Register Definitions */
#define IOTKIT_I2C_CONTROLC_SDA_Pos             1                                                    /* IOTKIT_I2C CONTROLC.SDA: SDA position */
#define IOTKIT_I2C_CONTROLC_SDA_Msk            (1UL << IOTKIT_I2C_CONTROLC_SDA_Pos)                  /* IOTKIT_I2C CONTROLC.SDA: SDA mask */

#define IOTKIT_I2C_CONTROLC_SCL_Pos             0                                                    /* IOTKIT_I2C CONTROLC.SCL: SCL position */
#define IOTKIT_I2C_CONTROLC_SCL_Msk            (1UL /*<< IOTKIT_I2C_CONTROLC_SCL_Pos*/)              /* IOTKIT_I2C CONTROLC.SCL: SCL mask */


/*------------------- PrimeCell Synchronous Serial Port (PL022) ----------------*/
typedef struct /* see "ARM PrimeCell Synchronous Serial Port (PL022) Technical Reference Manual r1p4" */
{
  __IOM uint32_t CR0;                        /* Offset: 0x000 (R/W)  Control register 0 */
  __IOM uint32_t CR1;                        /* Offset: 0x004 (R/W)  Control register 1 */
  __IOM uint32_t DR;                         /* Offset: 0x008 (R/W)  Data register */
  __IM  uint32_t SR;                         /* Offset: 0x00C (R/ )  Status register */
  __IOM uint32_t CPSR;                       /* Offset: 0x010 (R/W)  Clock prescale register */
  __IOM uint32_t IMSC;                       /* Offset: 0x014 (R/W)  Interrupt mask set or clear register */
  __IM  uint32_t RIS;                        /* Offset: 0x018 (R/ )  Raw interrupt status register */
  __IM  uint32_t MIS;                        /* Offset: 0x01C (R/ )  masked interrupt status register */
  __OM  uint32_t ICR;                        /* Offset: 0x020 ( /W)  Interrupt clear register */
  __IOM uint32_t DMACR;                      /* Offset: 0x024 (R/W)  DMA control register */
} IOTKIT_SSP_TypeDef;


/*------------------- PrimeCell Real Time Clock (PL031) ------------------------*/
typedef struct /* see "ARM PrimeCell Real Time Clock (PL031) Technical Reference Manual" */
{
  __IM  uint32_t DR;                         /* Offset: 0x000 (R/ )  Data register */
  __IOM uint32_t MR;                         /* Offset: 0x004 (R/W)  Match register */
  __IOM uint32_t LR;                         /* Offset: 0x008 (R/W)  Load register */
  __IOM uint32_t CR;                         /* Offset: 0x00C (R/W)  Control register */
  __IOM uint32_t IMSC;                       /* Offset: 0x010 (R/W)  Interrupt mask set and clear register */
  __OM  uint32_t RIS;                        /* Offset: 0x014 (R/ )  Raw interrupt status register */
  __OM  uint32_t MIS;                        /* Offset: 0x018 (R/ )  Masked interrupt status register */
  __IOM uint32_t ICR;                        /* Offset: 0x01C ( /W)  Interrupt clear register */
} IOTKIT_RTC_TypeDef;
 
  
/*------------------- PrimeCell Single Master DMA (PL081) ----------------------*/
typedef struct /* see "PrimeCell Single Master DMA Controller (PL081) Technical Reference Manual r1p2" */
{
  __IM   uint32_t IntStatus;                 /* Offset: 0x000 (R/ ) Interrupt Status Register */
  __IM   uint32_t IntTCStatus;               /* Offset: 0x004 (R/ ) Interrupt Terminal Count Status Register */
  __OM   uint32_t IntTCClear;                /* Offset: 0x008 (W/ ) Interrupt Terminal Count Clear Register */
  __IM   uint32_t IntErrorStatus;            /* Offset: 0x00C (R/ ) Interrupt Error Status Register */
  __OM   uint32_t IntErrClr;                 /* Offset: 0x010 (W/ ) Interrupt Error Clear Register */
  __IM   uint32_t RawIntTCStatus;            /* Offset: 0x014 (R/ ) Raw Interrupt Terminal Count Status Register */
  __IM   uint32_t RawIntErrorStatus;         /* Offset: 0x018 (R/ ) Raw Error Interrupt Status Register */
  __IM   uint32_t EnbldChns;                 /* Offset: 0x01C (R/ ) Enabled Channel Register */
  __IOM  uint32_t SoftBReq;                  /* Offset: 0x020 (R/W) Software Burst Request Register */
  __IOM  uint32_t SoftSReq;                  /* Offset: 0x024 (R/W) Software Single Request Register */
  __IOM  uint32_t SoftLBReq;                 /* Offset: 0x028 (R/W) Software Last Burst Request Register */
  __IOM  uint32_t SoftLSReq;                 /* Offset: 0x02C (R/W) Software Last Single Request Register */
  __IOM  uint32_t Configuration;             /* Offset: 0x030 (R/W) Configuration Register */
  __IOM  uint32_t Sync;                      /* Offset: 0x034 (R/W) Synchronization Register */
         uint32_t RESERVED0[50];
  __IOM  uint32_t C0SrcAddr;                 /* Offset: 0x100 (R/W) Channel Source Address Registers */
  __IOM  uint32_t C0DestAddr;                /* Offset: 0x104 (R/W) Channel Destination Address Registers */
  __IOM  uint32_t C0LLI;                     /* Offset: 0x108 (R/W) Channel Linked List Item Register */
  __IOM  uint32_t C0Control;                 /* Offset: 0x10C (R/W) Channel Control Register */
  __IOM  uint32_t C0Configuration;           /* Offset: 0x110 (R/W) Channel Configuration Register */
         uint32_t RESERVED1[3];
  __IOM  uint32_t C1SrcAddr;                 /* Offset: 0x120 (R/W) Channel Source Address Register */
  __IOM  uint32_t C1DestAddr;                /* Offset: 0x124 (R/W) Channel Destination Address Register */
  __IOM  uint32_t C1LLI;                     /* Offset: 0x128 (R/W) Channel Linked List Item Register */
  __IOM  uint32_t C1Control;                 /* Offset: 0x12C (R/W) Channel Control Registers on page */
  __IOM  uint32_t C1Configuration;           /* Offset: 0x130 (R/W) Channel Configuration Register */
} IOTKIT_DMA_TypeDef;


/*------------------- SMSC9220 (Ethernet) ------------------------------------*/
typedef struct /* see "?" */
{
  __IM   uint32_t RX_DATA_PORT;              /* Offset: 0x000 (R/ ) Receive FIFO Ports */
         uint32_t RESERVED0[7];              
  __OM   uint32_t TX_DATA_PORT;              /* Offset: 0x020 ( /W) Transmit FIFO Ports */
         uint32_t RESERVED1[7];              
  __IM   uint32_t RX_STAT_PORT;              /* Offset: 0x040 (R/ ) Receive FIFO status port */
  __IM   uint32_t RX_STAT_PEEK;              /* Offset: 0x044 (R/ ) Receive FIFO status peek */
  __IM   uint32_t TX_STAT_PORT;              /* Offset: 0x048 (R/ ) Transmit FIFO status port */
  __IM   uint32_t TX_STAT_PEEK;              /* Offset: 0x04C (R/ ) Transmit FIFO status peek */
  __IM   uint32_t ID_REV;                    /* Offset: 0x050 (R/ ) Chip ID and Revision */
  __IOM  uint32_t IRQ_CFG;                   /* Offset: 0x054 (R/W) Main Interrupt Configuration */
  __IOM  uint32_t INT_STS;                   /* Offset: 0x058 (R/W) Interrupt Status */
  __IOM  uint32_t INT_EN;                    /* Offset: 0x05C (R/W) Interrupt Enable Register */
         uint32_t RESERVED3;                 /* Offset: 0x060 (R/W) Reserved for future use */
  __IM   uint32_t BYTE_TEST;                 /* Offset: 0x064 (R/ ) Read-only byte order testing register 87654321h */
  __IOM  uint32_t FIFO_INT;                  /* Offset: 0x068 (R/W) FIFO Level Interrupts */
  __IOM  uint32_t RX_CFG;                    /* Offset: 0x06C (R/W) Receive Configuration */
  __IOM  uint32_t TX_CFG;                    /* Offset: 0x070 (R/W) Transmit Configuration */
  __IOM  uint32_t HW_CFG;                    /* Offset: 0x074 (R/W) Hardware Configuration */
  __IOM  uint32_t RX_DP_CTL;                 /* Offset: 0x078 (R/W) RX Datapath Control */
  __IM   uint32_t RX_FIFO_INF;               /* Offset: 0x07C (R/ ) Receive FIFO Information */
  __IM   uint32_t TX_FIFO_INF;               /* Offset: 0x080 (R/W) Transmit FIFO Information */
  __IOM  uint32_t PMT_CTRL;                  /* Offset: 0x084 (R/W) Power Management Control */
  __IOM  uint32_t GPIO_CFG;                  /* Offset: 0x088 (R/W) General Purpose IO Configuration */
  __IOM  uint32_t GPT_CFG;                   /* Offset: 0x08C (R/W) General Purpose Timer Configuration */
  __IM   uint32_t GPT_CNT;                   /* Offset: 0x090 (R/W) General Purpose Timer Count */
         uint32_t RESERVED4;                 /* Offset: 0x094 (R/W) Reserved for future use */
  __IOM  uint32_t ENDIAN;                    /* Offset: 0x098 (R/W) WORD SWAP Register */
  __IM   uint32_t FREE_RUN;                  /* Offset: 0x09C (R/W) Free Run Counter */
  __IM   uint32_t RX_DROP;                   /* Offset: 0x0A0 (R/W) RX Dropped Frames Counter */
  __IOM  uint32_t MAC_CSR_CMD;               /* Offset: 0x0A4 (R/W) MAC CSR Synchronizer Command */
  __IOM  uint32_t MAC_CSR_DATA;              /* Offset: 0x0A8 (R/W) MAC CSR Synchronizer Data */
  __IOM  uint32_t AFC_CFG;                   /* Offset: 0x0AC (R/W) Automatic Flow Control Configuration */
  __IOM  uint32_t E2P_CMD;                   /* Offset: 0x0B0 (R/W) EEPROM Command */
  __IOM  uint32_t E2P_DATA;                  /* Offset: 0x0B4 (R/W) EEPROM Data */
} IOTKIT_ETH_TypeDef;

/*------------------- Color LCD (CLCD) ------------------------*/
typedef struct /* see "?" */
{
  __IOM uint32_t COM;                        /* Offset: 0x000 (R/W)   */
  __IOM uint32_t DAT;                        /* Offset: 0x004 (R/W)   */
  __IOM uint32_t RD;                         /* Offset: 0x008 (R/W)   */
  __IOM uint32_t RAW;                        /* Offset: 0x00C (R/W)   */
  __IOM uint32_t MASK;                       /* Offset: 0x010 (R/W)   */
  __IOM uint32_t STAT;                       /* Offset: 0x014 (R/W)   */
        uint32_t RESERVED0[13];              /* Offset: 0x018 (R/W)   */
  __IOM uint32_t MISC;                       /* Offset: 0x04C (R/W)   */
} IOTKIT_CLCD_TypeDef;

/* IOTKIT_CLDC_MISC Register Definitions */
#define IOTKIT_CLCD_MISC_CLCDBLCTRL_Pos        6                                                     /* IOTKIT_CLCD MISC.CLCDBLCTRL: CLCD_BL_CTRL position */
#define IOTKIT_CLCD_MISC_CLCDBLCTRL_Msk       (0x1UL << IOTKIT_CLCD_MISC_CLCDBLCTRL_Pos)             /* IOTKIT_CLCD MISC.CLCDBLCTRL: CLCD_BL_CTRL mask */

#define IOTKIT_CLCD_MISC_CLCDRD_Pos            5                                                     /* IOTKIT_CLCD MISC.CLCDRD: CLCD_RD position */
#define IOTKIT_CLCD_MISC_CLCDRD_Msk           (0x1UL << IOTKIT_CLCD_MISC_CLCDRD_Pos)                 /* IOTKIT_CLCD MISC.CLCDRD: CLCD_RD mask */

#define IOTKIT_CLCD_MISC_CLCDRS_Pos            4                                                     /* IOTKIT_CLCD MISC.CLCDRS: CLCD_RS position */
#define IOTKIT_CLCD_MISC_CLCDRS_Msk           (0x1UL << IOTKIT_CLCD_MISC_CLCDRS_Pos)                 /* IOTKIT_CLCD MISC.CLCDRS: CLCD_RS mask */

#define IOTKIT_CLCD_MISC_CLCDRESET_Pos         3                                                     /* IOTKIT_CLCD MISC.CLCDRESET: CLCD_RESET position */
#define IOTKIT_CLCD_MISC_CLCDRESET_Msk        (0x1UL << IOTKIT_CLCD_MISC_CLCDRESET_Pos)              /* IOTKIT_CLCD MISC.CLCDRESET: CLCD_RESET mask */

#define IOTKIT_CLCD_MISC_CLCDCS_Pos            0                                                     /* IOTKIT_CLCD MISC.CLCDCS: CLCD_CS position */
#define IOTKIT_CLCD_MISC_CLCDCS_Msk           (0x1UL /*<< IOTKIT_CLCD_MISC_CLCDCS_Pos*/)             /* IOTKIT_CLCD MISC.CLCDCS: CLCD_CS mask */


/*------------------- Memory Protection Controller -------------------------------*/
typedef struct /* see "ARM CoreLink SSE-200 Subsystem Technical Reference Manual r0p0" */
{
  __IOM  uint32_t CTRL;                     /* Offset: 0x000 (R/W) Control Register */
         uint32_t RESERVED0[3];
  __IM   uint32_t BLK_MAX;                  /* Offset: 0x010 (R/ ) Block Maximum Register */
  __IM   uint32_t BLK_CFG;                  /* Offset: 0x014 (R/ ) Block Configuration Register */
  __IOM  uint32_t BLK_IDX;                  /* Offset: 0x018 (R/W) Block Index Register */
  __IOM  uint32_t BLK_LUT;                  /* Offset: 0x01C (R/W) Block Lookup Tabe Register */
  __IM   uint32_t INT_STAT;                 /* Offset: 0x020 (R/ ) Interrupt Status Register */
  __OM   uint32_t INT_CLEAR;                /* Offset: 0x024 ( /W) Interrupt Clear Register */
  __IOM  uint32_t INT_EN;                   /* Offset: 0x028 (R/W) Interrupt Enable Register */
  __IM   uint32_t INT_INFO1;                /* Offset: 0x02C (R/ ) Interrupt Info1 Register */
  __IM   uint32_t INT_INFO2;                /* Offset: 0x030 (R/ ) Interrupt Info2 Register */
  __OM   uint32_t INT_SET;                  /* Offset: 0x034 ( /W) Interrupt Set Register */
} IOTKIT_MPC_TypeDef;


/*------------------- Secure Privilege Control Block -----------------------------*/
typedef struct /* see "ARM CoreLink SSE-200 Subsystem Technical Reference Manual r0p0" */
{
  __IOM  uint32_t SPCSECCTRL;               /* Offest: 0x000 (R/W) Secure Privilege Controller Secure Configuration Control register */
  __IOM  uint32_t BUSWAIT;                  /* Offest: 0x004 (R/W) Bus Access wait control after reset */
         uint32_t RESERVED0[2U];
  __IOM  uint32_t SECRESPCFG;               /* Offset: 0x010 (R/W) Security Violation Response Configuration Register */
  __IOM  uint32_t NSCCFG;                   /* Offset: 0x014 (R/W) Non Secure Callable Configuration for IDAU */
         uint32_t RESERVED1[1U];
  __IM   uint32_t SECMPCINTSTATUS;          /* Offset: 0x01C (R/ ) Secure MPC Interrupt Status */
  __IM   uint32_t SECPPCINTSTAT;            /* Offset: 0x020 (R/ ) Secure PPC Interrupt Status */
  __OM   uint32_t SECPPCINTCLR;             /* Offset: 0x024 ( /W) Secure PPC Interrupt Clear */
  __IOM  uint32_t SECPPCINTEN;              /* Offset: 0x028 (R/W) Secure PPC Interrupt Enable */
         uint32_t RESERVED2[1U];
  __IM   uint32_t SECMSCINTSTAT;            /* Offset: 0x030 (R/ ) Secure MSC Interrupt Status */
  __OM   uint32_t SECMSCINTCLR;             /* Offset: 0x034 ( /W) Secure MSC Interrupt Clear */
  __IOM  uint32_t SECMSCINTEN;              /* Offset: 0x038 (R/W) Secure MSC Interrupt Enable */
         uint32_t RESERVED3[1U];
  __IM   uint32_t BRGINTSTAT;               /* Offset: 0x040 (R/ ) Bridge Buffer Error Interrupt Status */
  __OM   uint32_t BRGINTCLR;                /* Offset: 0x044 ( /W) Bridge Buffer Error Interrupt Clear */
  __IOM  uint32_t BRGINTEN;                 /* Offset: 0x048 (R/W) Bridge Buffer Error Interrupt Enable */
         uint32_t RESERVED4[1U];
  __IOM  uint32_t AHBNSPPC[4U];             /* Offset: 0x050 (R/W) Non-Secure Access AHB slave Peripheral Protection Control */
  __IOM  uint32_t AHBNSPPCEXP[4U];          /* Offset: 0x060 (R/W) Expansion Non_Secure Access AHB slave Peripheral Protection Control */
  __IOM  uint32_t APBNSPPC[4U];             /* Offset: 0x070 (R/W) Non-Secure Access APB slave Peripheral Protection Control */
  __IOM  uint32_t APBNSPPCEXP[4U];          /* Offset: 0x080 (R/W) Expansion Non_Secure Access APB slave Peripheral Protection Control */
  __IM   uint32_t AHBSPPPC[4U];             /* Offset: 0x090 (R/ ) Secure Unprivileged Access AHB slave Peripheral Protection Control */
  __IOM  uint32_t AHBSPPPCEXP[4U];          /* Offset: 0x0A0 (R/W) Expansion Secure Unprivileged Access AHB slave Peripheral Protection Control */
  __IOM  uint32_t APBSPPPC[4U];             /* Offset: 0x0B0 (R/W) Secure Unprivileged Access APB slave Peripheral Protection Control */
  __IOM  uint32_t APBSPPPCEXP[4U];          /* Offset: 0x0C0 (R/W) Expansion Secure Unprivileged Access APB slave Peripheral Protection Control */
  __IM   uint32_t NSMSCEXP;                 /* Offset: 0x0D0 (R/ ) Expansion MSC Non-Secure Configuration */
} IOTKIT_SPC_TypeDef;


/*------------------- Non-Secure Privilege Control Block -------------------------*/
typedef struct /* see "ARM CoreLink SSE-200 Subsystem Technical Reference Manual r0p0" */
{
         uint32_t RESERVED0[36U];
  __IOM  uint32_t AHBNSPPPC[4U];            /* Offset: 0x090 (R/W)  read-write 0x0000_0000 Non-Secure Unprivileged Access AHB slave Peripheral Protection Control */
  __IOM  uint32_t AHBNSPPPCEXP[4U];         /* Offset: 0x0A0 (R/W)  read-write 0x0000_0000 Expansion 0 Non-Secure Unprivileged Access AHB slave Peripheral Protection Control */
  __IOM  uint32_t APBNSPPPC[4U];            /* Offset: 0x0B0 (R/W)  read-write 0x0000_0000 Non-Secure Unprivileged Access APB slave Peripheral Protection Control */
  __IOM  uint32_t APBNSPPPCEXP[4U];         /* Offset: 0x0C0 (R/W)  read-write 0x0000_0000 Expansion 0 Non-Secure Unprivileged Access APB slave Peripheral Protection Control */
} IOTKIT_NSPC_TypeDef;


/* --------------------  End of section using anonymous unions  ------------------*/
#if   defined (__CC_ARM)
  #pragma pop
#elif defined (__ICCARM__)
  /* leave anonymous unions enabled */
#elif (__ARMCC_VERSION >= 6010050)
  #pragma clang diagnostic pop
#elif defined (__GNUC__)
  /* anonymous unions are enabled by default */
#elif defined (__TMS470__)
  /* anonymous unions are enabled by default */
#elif defined (__TASKING__)
  #pragma warning restore
#elif defined (__CSMC__)
  /* anonymous unions are enabled by default */
#else
  #warning Not supported compiler type
#endif




/* ================================================================================ */
/* ================              Peripheral memory map             ================ */
/* ================================================================================ */

/* --- peripherals */
#define IOTKIT_TIMER0_BASE               (0x40000000UL)       /* Timer 0 */
#define IOTKIT_TIMER1_BASE               (0x40001000UL)       /* Timer 1 */
#define IOTKIT_DUALTIMER_BASE            (0x40002000UL)       /* Dual input timer  */
#define IOTKIT_DUALTIMER_1_BASE          (0x40002000UL)       /* Dual input timer 1 */
#define IOTKIT_DUALTIMER_2_BASE          (0x40002020UL)       /* Dual input timer 2 */
#define IOTKIT_WATCHDOG_BASE             (0x40081000UL)       /* Watchdog */

/* --- peripherals */
#define IOTKIT_GPIO0_BASE                (0x40100000UL)       /* GPIO 0 */
#define IOTKIT_GPIO1_BASE                (0x40101000UL)       /* GPIO 1 */
#define IOTKIT_GPIO2_BASE                (0x40102000UL)       /* GPIO 2 */
#define IOTKIT_GPIO3_BASE                (0x40103000UL)       /* GPIO 3 */
#define IOTKIT_DMA0_BASE                 (0x40110000UL)       /* DMA 0 */
#define IOTKIT_DMA1_BASE                 (0x40111000UL)       /* DMA 1 */
#define IOTKIT_DMA2_BASE                 (0x40112000UL)       /* DMA 2 */
#define IOTKIT_DMA3_BASE                 (0x40113000UL)       /* DMA 3 */
#define IOTKIT_SDIO_BASE                 (0x40204000UL)       /* SDIO */
#define IOTKIT_HDLCD_BASE                (0x40205000UL)       /* HDLCD */
#define IOTKIT_EMMC_BASE                 (0x40206000UL)       /* eMMC */
#define IOTKIT_I2C0_BASE                 (0x40207000UL)       /* FPGA - SBCon I2C (Touch) */
#define IOTKIT_I2C1_BASE                 (0x40208000UL)       /* FPGA - SBCon I2C (Audio Conf */
#define IOTKIT_SPI0_BASE                 (0x40209000UL)       /* FPGA - PL022 (SPI ADC) */
#define IOTKIT_SPI1_BASE                 (0x4020A000UL)       /* FPGA - PL022 (SPI Shield0) */
#define IOTKIT_SPI2_BASE                 (0x4020B000UL)       /* FPGA - PL022 (SPI Shield1) */
#define IOTKIT_I2C2_BASE                 (0x4020C000UL)       /* SBCon (I2C - Shiled0) */
#define IOTKIT_I2C3_BASE                 (0x4020D000UL)       /* SBCon (I2C - Shiled1) */
#define IOTKIT_I2C4_BASE                 (0x4020E000UL)       /* I2C HDMI */
#define IOTKIT_SCC_BASE                  (0x40300000UL)       /* FPGA - SCC registers */
#define IOTKIT_I2S0_BASE                 (0x40301000UL)       /* FPGA - I2S (Audio) */
#define IOTKIT_FPGAIO_BASE               (0x40302000UL)       /* FPGA - IO ( Sytem Ctrl + I/O) */
#define IOTKIT_UART0_BASE                (0x40303000UL)       /* UART0 - UART_F[0] */
#define IOTKIT_UART1_BASE                (0x40304000UL)       /* UART1 - UART_F[1 */
#define IOTKIT_UART2_BASE                (0x40305000UL)       /* UART2 - UART_F[2] */
#define IOTKIT_UART3_BASE                (0x40306000UL)       /* UART3 - UART Shield 0 */
#define IOTKIT_UART4_BASE                (0x40307000UL)       /* UART4 - UART Shield 1 */
#define IOTKIT_UART5_BASE                (0x40308000UL)       /* UART5 - UART_F[3] */
#define IOTKIT_I2S1_BASE                 (0x40309000UL)       /* HDMI Audio */
#define IOTKIT_CLCD_BASE                 (0x4030A000UL)       /* Color LCD */
#define IOTKIT_RTC_BASE                  (0x4030B000UL)       /* RTC */
#define IOTKIT_ETH_BASE                  (0x40400000UL)       /* Ethernet */
#define IOTKIT_USB_BASE                  (0x40500000UL)       /* USB */
//#define IOTKIT_NIC400_BASE               (0x41000000UL)       /* NIC400 config (remap) */
//#define IOTKIT_  _BASE                   (0x48007000UL)       /* FPGA Non-Secure Privilege Control */


#define IOTKIT_SYSCTRL_BASE      (0x40116000UL)

#define IOTKIT_NSPC_BASE         (0x40080000UL)
#define IOTKIT_SPC_BASE          (0x50080000UL)
#define IOTKIT_MPCSRAM0_BASE     (0x50083000UL)
#define IOTKIT_MPCSRAM1_BASE     (0x50084000UL)
#define IOTKIT_MPCSRAM2_BASE     (0x50085000UL)
#define IOTKIT_MPCSRAM3_BASE     (0x50086000UL)
#define IOTKIT_MPCSSRAM_BASE     (0x58009000UL)


/* ================================================================================ */
/* ================          Secure Peripheral memory map          ================ */
/* ================================================================================ */

/* --- peripherals */
#define IOTKIT_SECURE_TIMER0_BASE        (0x50000000UL)
#define IOTKIT_SECURE_TIMER1_BASE        (0x50001000UL)
#define IOTKIT_SECURE_DUALTIMER_BASE     (0x50002000UL)
#define IOTKIT_SECURE_DUALTIMER_1_BASE   (0x50002000UL)       /* Dual input timer 1 */
#define IOTKIT_SECURE_DUALTIMER_2_BASE   (0x50002020UL)       /* Dual input timer 2 */
#define IOTKIT_SECURE_WATCHDOG_BASE      (0x50081000UL)       /* Watchdog */

/* AHB peripherals */
#define IOTKIT_SECURE_GPIO0_BASE         (0x50100000UL)       /* GPIO 0 */
#define IOTKIT_SECURE_GPIO1_BASE         (0x50101000UL)       /* GPIO 1 */
#define IOTKIT_SECURE_GPIO2_BASE         (0x50102000UL)       /* GPIO 2 */
#define IOTKIT_SECURE_GPIO3_BASE         (0x50103000UL)       /* GPIO 3 */
#define IOTKIT_SECURE_DMA0_BASE          (0x50110000UL)       /* DMA 0 */
#define IOTKIT_SECURE_DMA1_BASE          (0x50111000UL)       /* DMA 1 */
#define IOTKIT_SECURE_DMA2_BASE          (0x50112000UL)       /* DMA 2 */
#define IOTKIT_SECURE_DMA3_BASE          (0x50113000UL)       /* DMA 3 */
#define IOTKIT_SECURE_SDIO_BASE          (0x50204000UL)       /* SDIO */
#define IOTKIT_SECURE_HDLCD_BASE         (0x50205000UL)       /* HDLCD */
#define IOTKIT_SECURE_EMMC_BASE          (0x50206000UL)       /* eMMC */
#define IOTKIT_SECURE_I2C0_BASE          (0x50207000UL)       /* FPGA - SBCon I2C (Touch) */
#define IOTKIT_SECURE_I2C1_BASE          (0x50208000UL)       /* FPGA - SBCon I2C (Audio Conf */
#define IOTKIT_SECURE_SPI0_BASE          (0x50209000UL)       /* FPGA - PL022 (SPI ADC) */
#define IOTKIT_SECURE_SPI1_BASE          (0x5020A000UL)       /* FPGA - PL022 (SPI Shield0) */
#define IOTKIT_SECURE_SPI2_BASE          (0x5020B000UL)       /* FPGA - PL022 (SPI Shield1) */
#define IOTKIT_SECURE_I2C2_BASE          (0x5020C000UL)       /* SBCon (I2C - Shiled0) */
#define IOTKIT_SECURE_I2C3_BASE          (0x5020D000UL)       /* SBCon (I2C - Shiled1) */
#define IOTKIT_SECURE_I2C4_BASE          (0x5020E000UL)       /* I2C HDMI */
#define IOTKIT_SECURE_SCC_BASE           (0x50300000UL)       /* FPGA - SCC registers */
#define IOTKIT_SECURE_I2S0_BASE          (0x50301000UL)       /* FPGA - I2S (Audio) */
#define IOTKIT_SECURE_FPGAIO_BASE        (0x50302000UL)       /* FPGA - IO ( Sytem Ctrl + I/O) */
#define IOTKIT_SECURE_UART0_BASE         (0x50303000UL)       /* UART0 - UART_F[0] */
#define IOTKIT_SECURE_UART1_BASE         (0x50304000UL)       /* UART1 - UART_F[1 */
#define IOTKIT_SECURE_UART2_BASE         (0x50305000UL)       /* UART2 - UART_F[2] */
#define IOTKIT_SECURE_UART3_BASE         (0x50306000UL)       /* UART3 - UART Shield 0 */
#define IOTKIT_SECURE_UART4_BASE         (0x50307000UL)       /* UART4 - UART Shield 1 */
#define IOTKIT_SECURE_UART5_BASE         (0x50308000UL)       /* UART5 - UART_F[3] */
#define IOTKIT_SECURE_I2S1_BASE          (0x50309000UL)       /* HDMI Audio */
#define IOTKIT_SECURE_CLCD_BASE          (0x5030A000UL)       /* Color LCD */
#define IOTKIT_SECURE_RTC_BASE           (0x5030B000UL)       /* RTC */
#define IOTKIT_SECURE_ETH_BASE           (0x50400000UL)       /* Ethernet */
#define IOTKIT_SECURE_USB_BASE           (0x50500000UL)       /* USB */
//#define IOTKIT_SECURE_NIC400_BASE        (0x51000000UL)       /* NIC400 config (remap) */
//#define IOTKIT_SECURE_  _BASE            (0x58007000UL)       /* FPGA Non-Secure Privilege Control */



#define IOTKIT_SECURE_SYSCTRL_BASE      (0x50116000UL)


/* ================================================================================ */
/* ================             Peripheral declaration             ================ */
/* ================================================================================ */
#define IOTKIT_TIMER0            ((IOTKIT_TIMER_TypeDef            *) IOTKIT_TIMER0_BASE)
#define IOTKIT_TIMER1            ((IOTKIT_TIMER_TypeDef            *) IOTKIT_TIMER1_BASE)
#define IOTKIT_DUALTIMER         ((IOTKIT_DUALTIMER_TypeDef        *) IOTKIT_DUALTIMER_BASE)
#define IOTKIT_DUALTIMER1        ((IOTKIT_DUALTIMER_SINGLE_TypeDef *) IOTKIT_DUALTIMER_1_BASE)
#define IOTKIT_DUALTIMER2        ((IOTKIT_DUALTIMER_SINGLE_TypeDef *) IOTKIT_DUALTIMER_2_BASE)
#define IOTKIT_WATCHDOG          ((IOTKIT_WATCHDOG_TypeDef         *) IOTKIT_WATCHDOG_BASE)

#define IOTKIT_GPIO0             ((IOTKIT_GPIO_TypeDef             *) IOTKIT_GPIO0_BASE)
#define IOTKIT_GPIO1             ((IOTKIT_GPIO_TypeDef             *) IOTKIT_GPIO1_BASE)
#define IOTKIT_GPIO2             ((IOTKIT_GPIO_TypeDef             *) IOTKIT_GPIO2_BASE)
#define IOTKIT_GPIO3             ((IOTKIT_GPIO_TypeDef             *) IOTKIT_GPIO3_BASE)
#define IOTKIT_DMA0              ((IOTKIT_DMA_TypeDef              *) IOTKIT_DMA0_BASE)
#define IOTKIT_DMA1              ((IOTKIT_DMA_TypeDef              *) IOTKIT_DMA1_BASE)
#define IOTKIT_DMA2              ((IOTKIT_DMA_TypeDef              *) IOTKIT_DMA2_BASE)
#define IOTKIT_DMA3              ((IOTKIT_DMA_TypeDef              *) IOTKIT_DMA3_BASE)
#define IOTKIT_SDIO              ((IOTKIT_SDIO_TypeDef             *) IOTKIT_SDIO_BASE)
#define IOTKIT_HDLCD             ((IOTKIT_HDLCD_TypeDef            *) IOTKIT_HDLCD_BASE)
#define IOTKIT_EMMC              ((IOTKIT_EMMC_TypeDef             *) IOTKIT_EMMC_BASE)     
#define IOTKIT_I2C0              ((IOTKIT_I2C_TypeDef              *) IOTKIT_I2C0_BASE)      
#define IOTKIT_I2C1              ((IOTKIT_I2C_TypeDef              *) IOTKIT_I2C1_BASE)      
#define IOTKIT_SPI0              ((IOTKIT_SSP_TypeDef              *) IOTKIT_SPI0_BASE)      
#define IOTKIT_SPI1              ((IOTKIT_SSP_TypeDef              *) IOTKIT_SPI1_BASE)      
#define IOTKIT_SPI2              ((IOTKIT_SSP_TypeDef              *) IOTKIT_SPI2_BASE)      
#define IOTKIT_I2C2              ((IOTKIT_I2C_TypeDef              *) IOTKIT_I2C2_BASE)       
#define IOTKIT_I2C3              ((IOTKIT_I2C_TypeDef              *) IOTKIT_I2C3_BASE)      
#define IOTKIT_I2C4              ((IOTKIT_I2C_TypeDef              *) IOTKIT_I2C4_BASE)      
#define IOTKIT_SCC               ((IOTKIT_SCC_TypeDef              *) IOTKIT_SCC_BASE)       
#define IOTKIT_I2S0              ((IOTKIT_I2S_TypeDef              *) IOTKIT_I2S0_BASE)       
#define IOTKIT_FPGAIO            ((IOTKIT_FPGAIO_TypeDef           *) IOTKIT_FPGAIO_BASE)     
#define IOTKIT_UART0             ((IOTKIT_UART_TypeDef             *) IOTKIT_UART0_BASE)      
#define IOTKIT_UART1             ((IOTKIT_UART_TypeDef             *) IOTKIT_UART1_BASE)     
#define IOTKIT_UART2             ((IOTKIT_UART_TypeDef             *) IOTKIT_UART2_BASE)      
#define IOTKIT_UART3             ((IOTKIT_UART_TypeDef             *) IOTKIT_UART3_BASE)      
#define IOTKIT_UART4             ((IOTKIT_UART_TypeDef             *) IOTKIT_UART4_BASE)      
#define IOTKIT_UART5             ((IOTKIT_UART_TypeDef             *) IOTKIT_UART5_BASE)      
#define IOTKIT_I2S1              ((IOTKIT_I2S_TypeDef              *) IOTKIT_I2S1_BASE)       
#define IOTKIT_CLCD              ((IOTKIT_CLCD_TypeDef             *) IOTKIT_CLCD_BASE)       
#define IOTKIT_RTC               ((IOTKIT_RTC_TypeDef              *) IOTKIT_RTC_BASE)        
#define IOTKIT_ETH               ((IOTKIT_ETH_TypeDef              *) IOTKIT_ETH_BASE)        
//#define IOTKIT_USB               ((IOTKIT_USB_TypeDef              *) IOTKIT_USB_BASE)        
//#define IOTKIT_NIC400            ((IOTKIT_NIC400_TypeDef           *) IOTKIT_NIC400_BASE)     
//#define IOTKIT_                  ((IOTKIT_ _TypeDef                *) IOTKIT_ _BASE)         

#define IOTKIT_SYSCON            ((IOTKIT_SYSCON_TypeDef           *) IOTKIT_SYSCTRL_BASE)

#define IOTKIT_NSPC              ((IOTKIT_NSPC_TypeDef             *) IOTKIT_NSPC_BASE)
#define IOTKIT_SPC               ((IOTKIT_SPC_TypeDef              *) IOTKIT_SPC_BASE)
#define IOTKIT_MPCSRAM0          ((IOTKIT_MPC_TypeDef              *) IOTKIT_MPCSRAM0_BASE)
#define IOTKIT_MPCSRAM1          ((IOTKIT_MPC_TypeDef              *) IOTKIT_MPCSRAM1_BASE)
#define IOTKIT_MPCSRAM2          ((IOTKIT_MPC_TypeDef              *) IOTKIT_MPCSRAM2_BASE)
#define IOTKIT_MPCSRAM3          ((IOTKIT_MPC_TypeDef              *) IOTKIT_MPCSRAM3_BASE)
#define IOTKIT_MPCSSRAM          ((IOTKIT_MPC_TypeDef              *) IOTKIT_MPCSSRAM_BASE)


#define IOTKIT_SECURE_TIMER0     ((IOTKIT_TIMER_TypeDef            *) IOTKIT_SECURE_TIMER0_BASE)
#define IOTKIT_SECURE_TIMER1     ((IOTKIT_TIMER_TypeDef            *) IOTKIT_SECURE_TIMER1_BASE)
#define IOTKIT_SECURE_DUALTIMER  ((IOTKIT_DUALTIMER_TypeDef        *) IOTKIT_SECURE_DUALTIMER_BASE)
#define IOTKIT_SECURE_DUALTIMER1 ((IOTKIT_DUALTIMER_SINGLE_TypeDef *) IOTKIT_SECURE_DUALTIMER_1_BASE)
#define IOTKIT_SECURE_DUALTIMER2 ((IOTKIT_DUALTIMER_SINGLE_TypeDef *) IOTKIT_SECURE_DUALTIMER_2_BASE)
#define IOTKIT_SECURE_WATCHDOG   ((IOTKIT_WATCHDOG_TypeDef         *) IOTKIT_SECURE_WATCHDOG_BASE)

#define IOTKIT_SECURE_GPIO0      ((IOTKIT_GPIO_TypeDef             *) IOTKIT_SECURE_GPIO0_BASE)
#define IOTKIT_SECURE_GPIO1      ((IOTKIT_GPIO_TypeDef             *) IOTKIT_SECURE_GPIO1_BASE)
#define IOTKIT_SECURE_GPIO2      ((IOTKIT_GPIO_TypeDef             *) IOTKIT_SECURE_GPIO2_BASE)
#define IOTKIT_SECURE_GPIO3      ((IOTKIT_GPIO_TypeDef             *) IOTKIT_SECURE_GPIO3_BASE)
#define IOTKIT_SECURE_DMA0       ((IOTKIT_DMA_TypeDef              *) IOTKIT_SECURE_DMA0_BASE)
#define IOTKIT_SECURE_DMA1       ((IOTKIT_DMA_TypeDef              *) IOTKIT_SECURE_DMA1_BASE)
#define IOTKIT_SECURE_DMA2       ((IOTKIT_DMA_TypeDef              *) IOTKIT_SECURE_DMA2_BASE)
#define IOTKIT_SECURE_DMA3       ((IOTKIT_DMA_TypeDef              *) IOTKIT_SECURE_DMA3_BASE)
#define IOTKIT_SECURE_SDIO       ((IOTKIT_SDIO_TypeDef             *) IOTKIT_SECURE_SDIO_BASE)
#define IOTKIT_SECURE_HDLCD      ((IOTKIT_HDLCD_TypeDef            *) IOTKIT_SECURE_HDLCD_BASE)
#define IOTKIT_SECURE_EMMC       ((IOTKIT_EMMC_TypeDef             *) IOTKIT_SECURE_EMMC_BASE)     
#define IOTKIT_SECURE_I2C0       ((IOTKIT_I2C_TypeDef              *) IOTKIT_SECURE_I2C0_BASE)      
#define IOTKIT_SECURE_I2C1       ((IOTKIT_I2C_TypeDef              *) IOTKIT_SECURE_I2C1_BASE)      
#define IOTKIT_SECURE_SPI0       ((IOTKIT_SSP_TypeDef              *) IOTKIT_SECURE_SPI0_BASE)      
#define IOTKIT_SECURE_SPI1       ((IOTKIT_SSP_TypeDef              *) IOTKIT_SECURE_SPI1_BASE)      
#define IOTKIT_SECURE_SPI2       ((IOTKIT_SSP_TypeDef              *) IOTKIT_SECURE_SPI2_BASE)      
#define IOTKIT_SECURE_I2C2       ((IOTKIT_I2C_TypeDef              *) IOTKIT_SECURE_I2C2_BASE)       
#define IOTKIT_SECURE_I2C3       ((IOTKIT_I2C_TypeDef              *) IOTKIT_SECURE_I2C3_BASE)      
#define IOTKIT_SECURE_I2C4       ((IOTKIT_I2C_TypeDef              *) IOTKIT_SECURE_I2C4_BASE)      
#define IOTKIT_SECURE_SCC        ((IOTKIT_SCC_TypeDef              *) IOTKIT_SECURE_SCC_BASE)       
#define IOTKIT_SECURE_I2S0       ((IOTKIT_I2S_TypeDef              *) IOTKIT_SECURE_I2S0_BASE)       
#define IOTKIT_SECURE_FPGAIO     ((IOTKIT_FPGAIO_TypeDef           *) IOTKIT_SECURE_FPGAIO_BASE)     
#define IOTKIT_SECURE_UART0      ((IOTKIT_UART_TypeDef             *) IOTKIT_SECURE_UART0_BASE)      
#define IOTKIT_SECURE_UART1      ((IOTKIT_UART_TypeDef             *) IOTKIT_SECURE_UART1_BASE)     
#define IOTKIT_SECURE_UART2      ((IOTKIT_UART_TypeDef             *) IOTKIT_SECURE_UART2_BASE)      
#define IOTKIT_SECURE_UART3      ((IOTKIT_UART_TypeDef             *) IOTKIT_SECURE_UART3_BASE)      
#define IOTKIT_SECURE_UART4      ((IOTKIT_UART_TypeDef             *) IOTKIT_SECURE_UART4_BASE)      
#define IOTKIT_SECURE_UART5      ((IOTKIT_UART_TypeDef             *) IOTKIT_SECURE_UART5_BASE)      
#define IOTKIT_SECURE_I2S1       ((IOTKIT_I2S_TypeDef              *) IOTKIT_SECURE_I2S1_BASE)       
#define IOTKIT_SECURE_CLCD       ((IOTKIT_CLCD_TypeDef             *) IOTKIT_SECURE_CLCD_BASE)       
#define IOTKIT_SECURE_RTC        ((IOTKIT_RTC_TypeDef              *) IOTKIT_SECURE_RTC_BASE)        
#define IOTKIT_SECURE_ETH        ((IOTKIT_ETH_TypeDef              *) IOTKIT_SECURE_ETH_BASE)        
//#define IOTKIT_SECURE_USB        ((IOTKIT_USB_TypeDef              *) IOTKIT_SECURE_USB_BASE)        
//#define IOTKIT_SECURE_NIC400     ((IOTKIT_NIC400_TypeDef           *) IOTKIT_SECURE_NIC400_BASE)     
//#define IOTKIT_SECURE_           ((IOTKIT_ _TypeDef                *) IOTKIT_SECURE_ _BASE)         

#define IOTKIT_SECURE_SYSCON     ((IOTKIT_SYSCON_TypeDef           *) IOTKIT_SECURE_SYSCTRL_BASE)

#ifdef __cplusplus
}
#endif

#endif  /* IOTKit_CM33_H */
