/**************************************************************************//**
 * @file     startup_IOTKit_CM33.S
 * @brief    CMSIS Core Device Startup File for
 *           IOTKit_CM33 Device
 * @version  V1.0.0
 * @date     16. June 2017
 ******************************************************************************/
/* Copyright (c) 2011 - 2017 ARM LIMITED

   All rights reserved.
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:
   - Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
   - Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
   - Neither the name of ARM nor the names of its contributors may be used
     to endorse or promote products derived from this software without
     specific prior written permission.
   *
   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL COPYRIGHT HOLDERS AND CONTRIBUTORS BE
   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
   INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
   ---------------------------------------------------------------------------*/

	.syntax	unified
	.arch	armv7-m

	.section .stack
	.align	3
#ifdef __STACK_SIZE
	.equ	Stack_Size, __STACK_SIZE
#else
	.equ	Stack_Size, 0x00000400
#endif
	.globl	__StackTop
	.globl	__StackLimit
__StackLimit:
	.space	Stack_Size
	.size	__StackLimit, . - __StackLimit
__StackTop:
	.size	__StackTop, . - __StackTop

	.section .heap
	.align	3
#ifdef __HEAP_SIZE
	.equ	Heap_Size, __HEAP_SIZE
#else
	.equ	Heap_Size, 0x00000C00
#endif
	.globl	__HeapBase
	.globl	__HeapLimit
__HeapBase:
	.if	Heap_Size
	.space	Heap_Size
	.endif
	.size	__HeapBase, . - __HeapBase
__HeapLimit:
	.size	__HeapLimit, . - __HeapLimit

	.section .vectors
	.align	2
	.globl	__Vectors
__Vectors:
	.long	__StackTop                     /*      Top of Stack */
    .long   Reset_Handler                  /*      Reset Handler */
    .long   NMI_Handler                    /*      NMI Handler */
    .long   HardFault_Handler              /*      Hard Fault Handler */
    .long   MemManage_Handler              /*      MPU Fault Handler */
    .long   BusFault_Handler               /*      Bus Fault Handler */
    .long   UsageFault_Handler             /*      Usage Fault Handler */
    .long   SecureFault_Handler            /*      Secure Fault Handler */
    .long   0                              /*      Reserved */
    .long   0                              /*      Reserved */
    .long   0                              /*      Reserved */
    .long   SVC_Handler                    /*      SVCall Handler */
    .long   DebugMon_Handler               /*      Debug Monitor Handler */
    .long   0                              /*      Reserved */
    .long   PendSV_Handler                 /*      PendSV Handler */
    .long   SysTick_Handler                /*      SysTick Handler */

    /* Core IoT Interrupts */
    .long   NONSEC_WATCHDOG_RESET_Handler  /*   0  Non-Secure Watchdog Reset Request */
    .long   NONSEC_WATCHDOG_Handler        /*   1  Non-Secure Watchdog Interrupt */
    .long   S32K_TIMER_Handler             /*   2  S32K Timer */
    .long   TIMER0_Handler                 /*   3  Timer 0 */
    .long   TIMER1_Handler                 /*   4  Timer 1 */
    .long   DUALTIMER_Handler              /*   5  Dual Timer */
    .long   0                              /*   6  Reserved */
    .long   0                              /*   7  Reserved */
    .long   0                              /*   8  Reserved */
    .long   MPC_Handler                    /*   9  MPC Combined (Secure) */
    .long   PPC_Handler                    /*  10  PPC Combined (Secure) */
    .long   MSC_Handler                    /*  11  MSC Combined (Secure) */
    .long   BRIDGE_ERROR_Handler           /*  12  Bridge Error Combined Interrupt (Secure) */
    .long   0                              /*  13  Reserved */
    .long   0                              /*  14  Reserved */
    .long   0                              /*  15  Reserved */
    .long   0                              /*  16  Reserved */
    .long   0                              /*  17  Reserved */
    .long   0                              /*  18  Reserved */
    .long   0                              /*  19  Reserved */
    .long   0                              /*  20  Reserved */
    .long   0                              /*  21  Reserved */
    .long   0                              /*  22  Reserved */
    .long   0                              /*  23  Reserved */
    .long   0                              /*  24  Reserved */
    .long   0                              /*  25  Reserved */
    .long   0                              /*  26  Reserved */
    .long   0                              /*  27  Reserved */
    .long   0                              /*  28  Reserved */
    .long   0                              /*  29  Reserved */
    .long   0                              /*  30  Reserved */
    .long   0                              /*  31  Reserved */

    /* External Interrupts */
    .long   UART0RX_Handler                /*  32  UART 0 Receive Interrupt */
    .long   UART0TX_Handler                /*  33  UART 0 Transmit Interrupt */
    .long   UART1RX_Handler                /*  34  UART 1 Receive Interrupt */
    .long   UART1TX_Handler                /*  35  UART 1 Transmit Interrupt */
    .long   UART2RX_Handler                /*  36  UART 2 Receive Interrupt */
    .long   UART2TX_Handler                /*  37  UART 2 Transmit Interrupt */
    .long   UART3RX_Handler                /*  38  UART 3 Receive Interrupt */
    .long   UART3TX_Handler                /*  39  UART 3 Transmit Interrupt */
    .long   UART4RX_Handler                /*  40  UART 4 Receive Interrupt */
    .long   UART4TX_Handler                /*  41  UART 4 Transmit Interrupt */
    .long   UART0_Handler                  /*  42  UART 0 Combined Interrupt */
    .long   UART1_Handler                  /*  43  UART 1 Combined Interrupt */
    .long   UART2_Handler                  /*  44  UART 2 Combined Interrupt */
    .long   UART3_Handler                  /*  45  UART 3 Combined Interrupt */
    .long   UART4_Handler                  /*  46  UART 4 Combined Interrupt */
    .long   UARTOVF_Handler                /*  47  UART Overflow (0, 1, 2, 3, 4 & 5) Interrupt */
    .long   ETHERNET_Handler               /*  48  Ethernet */
    .long   I2S0_Handler                   /*  49  FPGA Audio I2S */
    .long   TSC_Handler                    /*  50  Touch Screen */
    .long   USB_Handler                    /*  51  USB */
    .long   SPI0_Handler                   /*  52  SPI ADC */
    .long   SPI1_Handler                   /*  53  SPI (Shield 0) */
    .long   SPI2_Handler                   /*  54  SPI (Shield 1) */
    .long   I2S1_Handler                   /*  55  HDMI Audio I2S */
    .long   DMA0_ERROR_Handler             /*  56  DMA #0 Error Interrupt Request */
    .long   DMA0_TC_Handler                /*  57  DMA #0 Terminal Count Interrupt Request */
    .long   DMA0_Handler                   /*  58  DMA #0 Combined Interrupt Request */
    .long   DMA1_ERROR_Handler             /*  59  DMA #1 Error Interrupt Request */
    .long   DMA1_TC_Handler                /*  60  DMA #1 Terminal Count Interrupt Request */
    .long   DMA1_Handler                   /*  61  DMA #1 Combined Interrupt Request */
    .long   DMA2_ERROR_Handler             /*  62  DMA #2 Error Interrupt Request */
    .long   DMA2_TC_Handler                /*  63  DMA #2 Terminal Count Interrupt Request */
    .long   DMA2_Handler                   /*  64  DMA #2 Combined Interrupt Request */
    .long   DMA3_ERROR_Handler             /*  65  DMA #3 Error Interrupt Request */
    .long   DMA3_TC_Handler                /*  66  DMA #3 Terminal Count Interrupt Request */
    .long   DMA3_Handler                   /*  67  DMA #3 Combined Interrupt Request */
    .long   GPIO0_Handler                  /*  68  GPIO 0 Combined Interrupt */
    .long   GPIO1_Handler                  /*  69  GPIO 1 Combined Interrupt */
    .long   GPIO2_Handler                  /*  70  GPIO 2 Combined Interrupt */
    .long   GPIO3_Handler                  /*  71  GPIO 3 Combined Interrupt */
    .long   GPIO0_0_Handler                /*  72  GPIO 0 individual interrupt 0 */
    .long   GPIO0_1_Handler                /*  73  GPIO 0 individual interrupt 1 */
    .long   GPIO0_2_Handler                /*  74  GPIO 0 individual interrupt 2 */
    .long   GPIO0_3_Handler                /*  75  GPIO 0 individual interrupt 3 */
    .long   GPIO0_4_Handler                /*  76  GPIO 0 individual interrupt 4 */
    .long   GPIO0_5_Handler                /*  77  GPIO 0 individual interrupt 5 */
    .long   GPIO0_6_Handler                /*  78  GPIO 0 individual interrupt 6 */
    .long   GPIO0_7_Handler                /*  79  GPIO 0 individual interrupt 7 */
    .long   GPIO0_8_Handler                /*  80  GPIO 0 individual interrupt 8 */
    .long   GPIO0_9_Handler                /*  81  GPIO 0 individual interrupt 9 */
    .long   GPIO0_10_Handler               /*  82  GPIO 0 individual interrupt 10 */
    .long   GPIO0_11_Handler               /*  83  GPIO 0 individual interrupt 11 */
    .long   GPIO0_12_Handler               /*  84  GPIO 0 individual interrupt 12 */
    .long   GPIO0_13_Handler               /*  85  GPIO 0 individual interrupt 13 */
    .long   GPIO0_14_Handler               /*  86  GPIO 0 individual interrupt 14 */
    .long   GPIO0_15_Handler               /*  87  GPIO 0 individual interrupt 15 */
    .long   GPIO1_0_Handler                /*  88  GPIO 1 individual interrupt 0 */
    .long   GPIO1_1_Handler                /*  89  GPIO 1 individual interrupt 1 */
    .long   GPIO1_2_Handler                /*  90  GPIO 1 individual interrupt 2 */
    .long   GPIO1_3_Handler                /*  91  GPIO 1 individual interrupt 3 */
    .long   GPIO1_4_Handler                /*  92  GPIO 1 individual interrupt 4 */
    .long   GPIO1_5_Handler                /*  93  GPIO 1 individual interrupt 5 */
    .long   GPIO1_6_Handler                /*  94  GPIO 1 individual interrupt 6 */
    .long   GPIO1_7_Handler                /*  95  GPIO 1 individual interrupt 7 */
    .long   GPIO1_8_Handler                /*  96  GPIO 1 individual interrupt 8 */
    .long   GPIO1_9_Handler                /*  97  GPIO 1 individual interrupt 9 */
    .long   GPIO1_10_Handler               /*  98  GPIO 1 individual interrupt 10 */
    .long   GPIO1_11_Handler               /*  99  GPIO 1 individual interrupt 11 */
    .long   GPIO1_12_Handler               /* 100  GPIO 1 individual interrupt 12 */
    .long   GPIO1_13_Handler               /* 101  GPIO 1 individual interrupt 13 */
    .long   GPIO1_14_Handler               /* 102  GPIO 1 individual interrupt 14 */
    .long   GPIO1_15_Handler               /* 103  GPIO 1 individual interrupt 15 */
    .long   GPIO2_0_Handler                /* 104  GPIO 2 individual interrupt 0 */
    .long   GPIO2_1_Handler                /* 105  GPIO 2 individual interrupt 1 */
    .long   GPIO2_2_Handler                /* 106  GPIO 2 individual interrupt 2 */
    .long   GPIO2_3_Handler                /* 107  GPIO 2 individual interrupt 3 */
    .long   GPIO2_4_Handler                /* 108  GPIO 2 individual interrupt 4 */
    .long   GPIO2_5_Handler                /* 109  GPIO 2 individual interrupt 5 */
    .long   GPIO2_6_Handler                /* 110  GPIO 2 individual interrupt 6 */
    .long   GPIO2_7_Handler                /* 111  GPIO 2 individual interrupt 7 */
    .long   GPIO2_8_Handler                /* 112  GPIO 2 individual interrupt 8 */
    .long   GPIO2_9_Handler                /* 113  GPIO 2 individual interrupt 9 */
    .long   GPIO2_10_Handler               /* 114  GPIO 2 individual interrupt 10 */
    .long   GPIO2_11_Handler               /* 115  GPIO 2 individual interrupt 11 */
    .long   GPIO2_12_Handler               /* 116  GPIO 2 individual interrupt 12 */
    .long   GPIO2_13_Handler               /* 117  GPIO 2 individual interrupt 13 */
    .long   GPIO2_14_Handler               /* 118  GPIO 2 individual interrupt 14 */
    .long   GPIO2_15_Handler               /* 119  GPIO 2 individual interrupt 15 */
    .long   GPIO3_0_Handler                /* 120  GPIO 3 individual interrupt 0 */
    .long   GPIO3_1_Handler                /* 121  GPIO 3 individual interrupt 1 */
    .long   GPIO3_2_Handler                /* 122  GPIO 3 individual interrupt 2 */
    .long   GPIO3_3_Handler                /* 123  GPIO 3 individual interrupt 3 */
    .long   UART5RX_Handler                /* 124  UART 5 Receive Interrupt */
    .long   UART5TX_Handler                /* 125  UART 5 Transmit Interrupt */
    .long   UART5_Handler                  /* 126  UART 5 Combined Interrupt */

	.size	__Vectors, . - __Vectors

	.text
	.thumb
	.thumb_func
	.align	2
	.globl	Reset_Handler
	.type	Reset_Handler, %function
Reset_Handler:
/*  Firstly it copies data from read only memory to RAM. There are two schemes
 *  to copy. One can copy more than one sections. Another can only copy
 *  one section.  The former scheme needs more instructions and read-only
 *  data to implement than the latter.
 *  Macro __STARTUP_COPY_MULTIPLE is used to choose between two schemes.  */

#ifdef __STARTUP_COPY_MULTIPLE
/*  Multiple sections scheme.
 *
 *  Between symbol address __copy_table_start__ and __copy_table_end__,
 *  there are array of triplets, each of which specify:
 *    offset 0: LMA of start of a section to copy from
 *    offset 4: VMA of start of a section to copy to
 *    offset 8: size of the section to copy. Must be multiply of 4
 *
 *  All addresses must be aligned to 4 bytes boundary.
 */
	ldr	r4, =__copy_table_start__
	ldr	r5, =__copy_table_end__

.L_loop0:
	cmp	r4, r5
	bge	.L_loop0_done
	ldr	r1, [r4]
	ldr	r2, [r4, #4]
	ldr	r3, [r4, #8]

.L_loop0_0:
	subs	r3, #4
	ittt	ge
	ldrge	r0, [r1, r3]
	strge	r0, [r2, r3]
	bge	.L_loop0_0

	adds	r4, #12
	b	.L_loop0

.L_loop0_done:
#else
/*  Single section scheme.
 *
 *  The ranges of copy from/to are specified by following symbols
 *    __etext: LMA of start of the section to copy from. Usually end of text
 *    __data_start__: VMA of start of the section to copy to
 *    __data_end__: VMA of end of the section to copy to
 *
 *  All addresses must be aligned to 4 bytes boundary.
 */
	ldr	r1, =__etext
	ldr	r2, =__data_start__
	ldr	r3, =__data_end__

.L_loop1:
	cmp	r2, r3
	ittt	lt
	ldrlt	r0, [r1], #4
	strlt	r0, [r2], #4
	blt	.L_loop1
#endif /*__STARTUP_COPY_MULTIPLE */

/*  This part of work usually is done in C library startup code. Otherwise,
 *  define this macro to enable it in this startup.
 *
 *  There are two schemes too. One can clear multiple BSS sections. Another
 *  can only clear one section. The former is more size expensive than the
 *  latter.
 *
 *  Define macro __STARTUP_CLEAR_BSS_MULTIPLE to choose the former.
 *  Otherwise efine macro __STARTUP_CLEAR_BSS to choose the later.
 */
#ifdef __STARTUP_CLEAR_BSS_MULTIPLE
/*  Multiple sections scheme.
 *
 *  Between symbol address __copy_table_start__ and __copy_table_end__,
 *  there are array of tuples specifying:
 *    offset 0: Start of a BSS section
 *    offset 4: Size of this BSS section. Must be multiply of 4
 */
	ldr	r3, =__zero_table_start__
	ldr	r4, =__zero_table_end__

.L_loop2:
	cmp	r3, r4
	bge	.L_loop2_done
	ldr	r1, [r3]
	ldr	r2, [r3, #4]
	movs	r0, 0

.L_loop2_0:
	subs	r2, #4
	itt	ge
	strge	r0, [r1, r2]
	bge	.L_loop2_0

	adds	r3, #8
	b	.L_loop2
.L_loop2_done:
#elif defined (__STARTUP_CLEAR_BSS)
/*  Single BSS section scheme.
 *
 *  The BSS section is specified by following symbols
 *    __bss_start__: start of the BSS section.
 *    __bss_end__: end of the BSS section.
 *
 *  Both addresses must be aligned to 4 bytes boundary.
 */
	ldr	r1, =__bss_start__
	ldr	r2, =__bss_end__

	movs	r0, 0
.L_loop3:
	cmp	r1, r2
	itt	lt
	strlt	r0, [r1], #4
	blt	.L_loop3
#endif /* __STARTUP_CLEAR_BSS_MULTIPLE || __STARTUP_CLEAR_BSS */

#ifndef __NO_SYSTEM_INIT
	bl	SystemInit
#endif

#ifndef __START
#define __START _start
#endif
	bl	__START

	.pool
	.size	Reset_Handler, . - Reset_Handler

	.align	1
	.thumb_func
	.weak	Default_Handler
	.type	Default_Handler, %function
Default_Handler:
	b	.
	.size	Default_Handler, . - Default_Handler

/*    Macro to define default handlers. Default handler
 *    will be weak symbol and just dead loops. They can be
 *    overwritten by other handlers */
	.macro	def_irq_handler	handler_name
	.weak	\handler_name
	.set	\handler_name, Default_Handler
	.endm

	def_irq_handler	NMI_Handler
    def_irq_handler HardFault_Handler
    def_irq_handler MemManage_Handler
    def_irq_handler BusFault_Handler
    def_irq_handler UsageFault_Handler
    def_irq_handler SecureFault_Handler
    def_irq_handler SVC_Handler
    def_irq_handler DebugMon_Handler
    def_irq_handler PendSV_Handler
    def_irq_handler SysTick_Handler

    def_irq_handler NONSEC_WATCHDOG_RESET_Handler
    def_irq_handler NONSEC_WATCHDOG_Handler
    def_irq_handler S32K_TIMER_Handler
    def_irq_handler TIMER0_Handler
    def_irq_handler TIMER1_Handler
    def_irq_handler DUALTIMER_Handler
    def_irq_handler MPC_Handler
    def_irq_handler PPC_Handler
    def_irq_handler MSC_Handler
    def_irq_handler BRIDGE_ERROR_Handler

    def_irq_handler UART0RX_Handler
    def_irq_handler UART0TX_Handler
    def_irq_handler UART1RX_Handler
    def_irq_handler UART1TX_Handler
    def_irq_handler UART2RX_Handler
    def_irq_handler UART2TX_Handler
    def_irq_handler UART3RX_Handler
    def_irq_handler UART3TX_Handler
    def_irq_handler UART4RX_Handler
    def_irq_handler UART4TX_Handler
    def_irq_handler UART0_Handler
    def_irq_handler UART1_Handler
    def_irq_handler UART2_Handler
    def_irq_handler UART3_Handler
    def_irq_handler UART4_Handler
    def_irq_handler UARTOVF_Handler
    def_irq_handler ETHERNET_Handler
    def_irq_handler I2S0_Handler
    def_irq_handler TSC_Handler
    def_irq_handler USB_Handler
    def_irq_handler SPI0_Handler
    def_irq_handler SPI1_Handler
    def_irq_handler SPI2_Handler
    def_irq_handler I2S1_Handler
    def_irq_handler DMA0_ERROR_Handler
    def_irq_handler DMA0_TC_Handler
    def_irq_handler DMA0_Handler
    def_irq_handler DMA1_ERROR_Handler
    def_irq_handler DMA1_TC_Handler
    def_irq_handler DMA1_Handler
    def_irq_handler DMA2_ERROR_Handler
    def_irq_handler DMA2_TC_Handler
    def_irq_handler DMA2_Handler
    def_irq_handler DMA3_ERROR_Handler
    def_irq_handler DMA3_TC_Handler
    def_irq_handler DMA3_Handler
    def_irq_handler GPIO0_Handler
    def_irq_handler GPIO1_Handler
    def_irq_handler GPIO2_Handler
    def_irq_handler GPIO3_Handler
    def_irq_handler GPIO0_0_Handler
    def_irq_handler GPIO0_1_Handler
    def_irq_handler GPIO0_2_Handler
    def_irq_handler GPIO0_3_Handler
    def_irq_handler GPIO0_4_Handler
    def_irq_handler GPIO0_5_Handler
    def_irq_handler GPIO0_6_Handler
    def_irq_handler GPIO0_7_Handler
    def_irq_handler GPIO0_8_Handler
    def_irq_handler GPIO0_9_Handler
    def_irq_handler GPIO0_10_Handler
    def_irq_handler GPIO0_11_Handler
    def_irq_handler GPIO0_12_Handler
    def_irq_handler GPIO0_13_Handler
    def_irq_handler GPIO0_14_Handler
    def_irq_handler GPIO0_15_Handler
    def_irq_handler GPIO1_0_Handler
    def_irq_handler GPIO1_1_Handler
    def_irq_handler GPIO1_2_Handler
    def_irq_handler GPIO1_3_Handler
    def_irq_handler GPIO1_4_Handler
    def_irq_handler GPIO1_5_Handler
    def_irq_handler GPIO1_6_Handler
    def_irq_handler GPIO1_7_Handler
    def_irq_handler GPIO1_8_Handler
    def_irq_handler GPIO1_9_Handler
    def_irq_handler GPIO1_10_Handler
    def_irq_handler GPIO1_11_Handler
    def_irq_handler GPIO1_12_Handler
    def_irq_handler GPIO1_13_Handler
    def_irq_handler GPIO1_14_Handler
    def_irq_handler GPIO1_15_Handler
    def_irq_handler GPIO2_0_Handler
    def_irq_handler GPIO2_1_Handler
    def_irq_handler GPIO2_2_Handler
    def_irq_handler GPIO2_3_Handler
    def_irq_handler GPIO2_4_Handler
    def_irq_handler GPIO2_5_Handler
    def_irq_handler GPIO2_6_Handler
    def_irq_handler GPIO2_7_Handler
    def_irq_handler GPIO2_8_Handler
    def_irq_handler GPIO2_9_Handler
    def_irq_handler GPIO2_10_Handler
    def_irq_handler GPIO2_11_Handler
    def_irq_handler GPIO2_12_Handler
    def_irq_handler GPIO2_13_Handler
    def_irq_handler GPIO2_14_Handler
    def_irq_handler GPIO2_15_Handler
    def_irq_handler GPIO3_0_Handler
    def_irq_handler GPIO3_1_Handler
    def_irq_handler GPIO3_2_Handler
    def_irq_handler GPIO3_3_Handler
    def_irq_handler UART5RX_Handler
    def_irq_handler UART5TX_Handler
    def_irq_handler UART5_Handler

	.end
