/**************************************************************************//**
 * @file     startup_IOTKit_CM33.c
 * @brief    CMSIS Core Device Startup File for
 *           IOTKit_CM33 Device (MPS3)
 * @version  V1.0.0
 * @date     16. June 2017
 ******************************************************************************/
/* Copyright (c) 2011 - 2017 ARM LIMITED

   All rights reserved.
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:
   - Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
   - Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
   - Neither the name of ARM nor the names of its contributors may be used
     to endorse or promote products derived from this software without
     specific prior written permission.
   *
   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL COPYRIGHT HOLDERS AND CONTRIBUTORS BE
   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
   INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
   ---------------------------------------------------------------------------*/

#include <stdint.h>


/*----------------------------------------------------------------------------
  Linker generated Symbols
 *----------------------------------------------------------------------------*/
extern uint32_t __etext;
extern uint32_t __data_start__;
extern uint32_t __data_end__;
extern uint32_t __copy_table_start__;
extern uint32_t __copy_table_end__;
extern uint32_t __zero_table_start__;
extern uint32_t __zero_table_end__;
extern uint32_t __bss_start__;
extern uint32_t __bss_end__;
extern uint32_t __StackTop;

/*----------------------------------------------------------------------------
  Exception / Interrupt Handler Function Prototype
 *----------------------------------------------------------------------------*/
typedef void( *pFunc )( void );


/*----------------------------------------------------------------------------
  External References
 *----------------------------------------------------------------------------*/
#ifndef __START
extern void  _start(void) __attribute__((noreturn));    /* PreeMain (C library entry point) */
#else
extern int  __START(void) __attribute__((noreturn));    /* main entry point */
#endif

#ifndef __NO_SYSTEM_INIT
extern void SystemInit (void);            /* CMSIS System Initialization      */
#endif


/*----------------------------------------------------------------------------
  Internal References
 *----------------------------------------------------------------------------*/
void Default_Handler(void);                          /* Default empty handler */
void Reset_Handler(void);                            /* Reset Handler */


/*----------------------------------------------------------------------------
  User Initial Stack & Heap
 *----------------------------------------------------------------------------*/
#ifndef __STACK_SIZE
  #define	__STACK_SIZE  0x00000400
#endif
static uint8_t stack[__STACK_SIZE] __attribute__ ((aligned(8), used, section(".stack")));

#ifndef __HEAP_SIZE
  #define	__HEAP_SIZE   0x00000C00
#endif
#if __HEAP_SIZE > 0
static uint8_t heap[__HEAP_SIZE]   __attribute__ ((aligned(8), used, section(".heap")));
#endif


/*----------------------------------------------------------------------------
  Exception / Interrupt Handler
 *----------------------------------------------------------------------------*/
/* Cortex-M3 Processor Exceptions */
void NMI_Handler                    (void) __attribute__ ((weak, alias("Default_Handler")));
void HardFault_Handler              (void) __attribute__ ((weak, alias("Default_Handler")));
void MemManage_Handler              (void) __attribute__ ((weak, alias("Default_Handler")));
void BusFault_Handler               (void) __attribute__ ((weak, alias("Default_Handler")));
void UsageFault_Handler             (void) __attribute__ ((weak, alias("Default_Handler")));
void SecureFault_Handler            (void) __attribute__ ((weak, alias("Default_Handler")));
void SVC_Handler                    (void) __attribute__ ((weak, alias("Default_Handler")));
void DebugMon_Handler               (void) __attribute__ ((weak, alias("Default_Handler")));
void PendSV_Handler                 (void) __attribute__ ((weak, alias("Default_Handler")));
void SysTick_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));

    /* Core IoT Interrupts */
void NONSEC_WATCHDOG_RESET_Handler  (void) __attribute__ ((weak, alias("Default_Handler")));
void NONSEC_WATCHDOG_Handler        (void) __attribute__ ((weak, alias("Default_Handler")));
void S32K_TIMER_Handler             (void) __attribute__ ((weak, alias("Default_Handler")));
void TIMER0_Handler                 (void) __attribute__ ((weak, alias("Default_Handler")));
void TIMER1_Handler                 (void) __attribute__ ((weak, alias("Default_Handler")));
void DUALTIMER_Handler              (void) __attribute__ ((weak, alias("Default_Handler")));
void MPC_Handler                    (void) __attribute__ ((weak, alias("Default_Handler")));
void PPC_Handler                    (void) __attribute__ ((weak, alias("Default_Handler")));
void MSC_Handler                    (void) __attribute__ ((weak, alias("Default_Handler")));
void BRIDGE_ERROR_Handler           (void) __attribute__ ((weak, alias("Default_Handler")));

    /* External Interrupts */
void UART0RX_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void UART0TX_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void UART1RX_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void UART1TX_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void UART2RX_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void UART2TX_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void UART3RX_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void UART3TX_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void UART4RX_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void UART4TX_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void UART0_Handler                  (void) __attribute__ ((weak, alias("Default_Handler")));
void UART1_Handler                  (void) __attribute__ ((weak, alias("Default_Handler")));
void UART2_Handler                  (void) __attribute__ ((weak, alias("Default_Handler")));
void UART3_Handler                  (void) __attribute__ ((weak, alias("Default_Handler")));
void UART4_Handler                  (void) __attribute__ ((weak, alias("Default_Handler")));
void UARTOVF_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void ETHERNET_Handler               (void) __attribute__ ((weak, alias("Default_Handler")));
void I2S0_Handler                   (void) __attribute__ ((weak, alias("Default_Handler")));
void TSC_Handler                    (void) __attribute__ ((weak, alias("Default_Handler")));
void USB_Handler                    (void) __attribute__ ((weak, alias("Default_Handler")));
void SPI0_Handler                   (void) __attribute__ ((weak, alias("Default_Handler")));
void SPI1_Handler                   (void) __attribute__ ((weak, alias("Default_Handler")));
void SPI2_Handler                   (void) __attribute__ ((weak, alias("Default_Handler")));
void I2S1_Handler                   (void) __attribute__ ((weak, alias("Default_Handler")));
void DMA0_ERROR_Handler             (void) __attribute__ ((weak, alias("Default_Handler")));
void DMA0_TC_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void DMA0_Handler                   (void) __attribute__ ((weak, alias("Default_Handler")));
void DMA1_ERROR_Handler             (void) __attribute__ ((weak, alias("Default_Handler")));
void DMA1_TC_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void DMA1_Handler                   (void) __attribute__ ((weak, alias("Default_Handler")));
void DMA2_ERROR_Handler             (void) __attribute__ ((weak, alias("Default_Handler")));
void DMA2_TC_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void DMA2_Handler                   (void) __attribute__ ((weak, alias("Default_Handler")));
void DMA3_ERROR_Handler             (void) __attribute__ ((weak, alias("Default_Handler")));
void DMA3_TC_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void DMA3_Handler                   (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO0_Handler                  (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO1_Handler                  (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO2_Handler                  (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO3_Handler                  (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO0_0_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO0_1_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO0_2_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO0_3_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO0_4_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO0_5_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO0_6_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO0_7_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO0_8_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO0_9_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO0_10_Handler               (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO0_11_Handler               (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO0_12_Handler               (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO0_13_Handler               (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO0_14_Handler               (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO0_15_Handler               (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO1_0_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO1_1_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO1_2_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO1_3_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO1_4_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO1_5_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO1_6_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO1_7_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO1_8_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO1_9_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO1_10_Handler               (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO1_11_Handler               (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO1_12_Handler               (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO1_13_Handler               (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO1_14_Handler               (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO1_15_Handler               (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO2_0_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO2_1_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO2_2_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO2_3_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO2_4_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO2_5_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO2_6_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO2_7_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO2_8_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO2_9_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO2_10_Handler               (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO2_11_Handler               (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO2_12_Handler               (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO2_13_Handler               (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO2_14_Handler               (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO2_15_Handler               (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO3_0_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO3_1_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO3_2_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void GPIO3_3_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void UART5RX_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void UART5TX_Handler                (void) __attribute__ ((weak, alias("Default_Handler")));
void UART5_Handler                  (void) __attribute__ ((weak, alias("Default_Handler")));


/*----------------------------------------------------------------------------
  Exception / Interrupt Vector table
 *----------------------------------------------------------------------------*/
const pFunc __Vectors[] __attribute__ ((section(".vectors"))) = {
  /* Cortex-M3 Exceptions Handler */
  (pFunc)((uint32_t)&__StackTop),           /*     Initial Stack Pointer */
  Reset_Handler,                            /*      Reset Handler */
  NMI_Handler,                              /*      NMI Handler */
  HardFault_Handler,                        /*      Hard Fault Handler */
  MemManage_Handler,                        /*      MPU Fault Handler */
  BusFault_Handler,                         /*      Bus Fault Handler */
  UsageFault_Handler,                       /*      Usage Fault Handler */
  SecureFault_Handler,                      /*      Secure Fault Handler */
  0,                                        /*      Reserved */
  0,                                        /*      Reserved */
  0,                                        /*      Reserved */
  SVC_Handler,                              /*      SVCall Handler */
  DebugMon_Handler,                         /*      Debug Monitor Handler */
  0,                                        /*      Reserved */
  PendSV_Handler,                           /*      PendSV Handler */
  SysTick_Handler,                          /*      SysTick Handler */

  /* Core IoT Interrupts */
  NONSEC_WATCHDOG_RESET_Handler,            /*   0  Non-Secure Watchdog Reset Request */
  NONSEC_WATCHDOG_Handler,                  /*   1  Non-Secure Watchdog Interrupt */
  S32K_TIMER_Handler,                       /*   2  S32K Timer */
  TIMER0_Handler,                           /*   3  Timer 0 */
  TIMER1_Handler,                           /*   4  Timer 1 */
  DUALTIMER_Handler,                        /*   5  Dual Timer */
  0,                                        /*   6  Reserved */
  0,                                        /*   7  Reserved */
  0,                                        /*   8  Reserved */
  MPC_Handler,                              /*   9  MPC Combined (Secure) */
  PPC_Handler,                              /*  10  PPC Combined (Secure) */
  MSC_Handler,                              /*  11  MSC Combined (Secure) */
  BRIDGE_ERROR_Handler,                     /*  12  Bridge Error Combined Interrupt (Secure) */
  0,                                        /*  13  Reserved */
  0,                                        /*  14  Reserved */
  0,                                        /*  15  Reserved */
  0,                                        /*  16  Reserved */
  0,                                        /*  17  Reserved */
  0,                                        /*  18  Reserved */
  0,                                        /*  19  Reserved */
  0,                                        /*  20  Reserved */
  0,                                        /*  21  Reserved */
  0,                                        /*  22  Reserved */
  0,                                        /*  23  Reserved */
  0,                                        /*  24  Reserved */
  0,                                        /*  25  Reserved */
  0,                                        /*  26  Reserved */
  0,                                        /*  27  Reserved */
  0,                                        /*  28  Reserved */
  0,                                        /*  29  Reserved */
  0,                                        /*  30  Reserved */
  0,                                        /*  31  Reserved */

    /* External Interrupts */
  UART0RX_Handler,                          /*  32  UART 0 Receive Interrupt */
  UART0TX_Handler,                          /*  33  UART 0 Transmit Interrupt */
  UART1RX_Handler,                          /*  34  UART 1 Receive Interrupt */
  UART1TX_Handler,                          /*  35  UART 1 Transmit Interrupt */
  UART2RX_Handler,                          /*  36  UART 2 Receive Interrupt */
  UART2TX_Handler,                          /*  37  UART 2 Transmit Interrupt */
  UART3RX_Handler,                          /*  38  UART 3 Receive Interrupt */
  UART3TX_Handler,                          /*  39  UART 3 Transmit Interrupt */
  UART4RX_Handler,                          /*  40  UART 4 Receive Interrupt */
  UART4TX_Handler,                          /*  41  UART 4 Transmit Interrupt */
  UART0_Handler,                            /*  42  UART 0 Combined Interrupt */
  UART1_Handler,                            /*  43  UART 1 Combined Interrupt */
  UART2_Handler,                            /*  44  UART 2 Combined Interrupt */
  UART3_Handler,                            /*  45  UART 3 Combined Interrupt */
  UART4_Handler,                            /*  46  UART 4 Combined Interrupt */
  UARTOVF_Handler,                          /*  47  UART Overflow (0, 1, 2, 3, 4 & 5) Interrupt */
  ETHERNET_Handler,                         /*  48  Ethernet */
  I2S0_Handler,                             /*  49  FPGA Audio I2S */
  TSC_Handler,                              /*  50  Touch Screen */
  USB_Handler,                              /*  51  USB */
  SPI0_Handler,                             /*  52  SPI ADC */
  SPI1_Handler,                             /*  53  SPI (Shield 0) */
  SPI2_Handler,                             /*  54  SPI (Shield 1) */
  I2S1_Handler,                             /*  55  HDMI Audio I2S */
  DMA0_ERROR_Handler,                       /*  56  DMA #0 Error Interrupt Request */
  DMA0_TC_Handler,                          /*  57  DMA #0 Terminal Count Interrupt Request */
  DMA0_Handler,                             /*  58  DMA #0 Combined Interrupt Request */
  DMA1_ERROR_Handler,                       /*  59  DMA #1 Error Interrupt Request */
  DMA1_TC_Handler,                          /*  60  DMA #1 Terminal Count Interrupt Request */
  DMA1_Handler,                             /*  61  DMA #1 Combined Interrupt Request */
  DMA2_ERROR_Handler,                       /*  62  DMA #2 Error Interrupt Request */
  DMA2_TC_Handler,                          /*  63  DMA #2 Terminal Count Interrupt Request */
  DMA2_Handler,                             /*  64  DMA #2 Combined Interrupt Request */
  DMA3_ERROR_Handler,                       /*  65  DMA #3 Error Interrupt Request */
  DMA3_TC_Handler,                          /*  66  DMA #3 Terminal Count Interrupt Request */
  DMA3_Handler,                             /*  67  DMA #3 Combined Interrupt Request */
  GPIO0_Handler,                            /*  68  GPIO 0 Combined Interrupt */
  GPIO1_Handler,                            /*  69  GPIO 1 Combined Interrupt */
  GPIO2_Handler,                            /*  70  GPIO 2 Combined Interrupt */
  GPIO3_Handler,                            /*  71  GPIO 3 Combined Interrupt */
  GPIO0_0_Handler,                          /*  72  GPIO 0 individual interrupt 0 */
  GPIO0_1_Handler,                          /*  73  GPIO 0 individual interrupt 1 */
  GPIO0_2_Handler,                          /*  74  GPIO 0 individual interrupt 2 */
  GPIO0_3_Handler,                          /*  75  GPIO 0 individual interrupt 3 */
  GPIO0_4_Handler,                          /*  76  GPIO 0 individual interrupt 4 */
  GPIO0_5_Handler,                          /*  77  GPIO 0 individual interrupt 5 */
  GPIO0_6_Handler,                          /*  78  GPIO 0 individual interrupt 6 */
  GPIO0_7_Handler,                          /*  79  GPIO 0 individual interrupt 7 */
  GPIO0_8_Handler,                          /*  80  GPIO 0 individual interrupt 8 */
  GPIO0_9_Handler,                          /*  81  GPIO 0 individual interrupt 9 */
  GPIO0_10_Handler,                         /*  82  GPIO 0 individual interrupt 10 */
  GPIO0_11_Handler,                         /*  83  GPIO 0 individual interrupt 11 */
  GPIO0_12_Handler,                         /*  84  GPIO 0 individual interrupt 12 */
  GPIO0_13_Handler,                         /*  85  GPIO 0 individual interrupt 13 */
  GPIO0_14_Handler,                         /*  86  GPIO 0 individual interrupt 14 */
  GPIO0_15_Handler,                         /*  87  GPIO 0 individual interrupt 15 */
  GPIO1_0_Handler,                          /*  88  GPIO 1 individual interrupt 0 */
  GPIO1_1_Handler,                          /*  89  GPIO 1 individual interrupt 1 */
  GPIO1_2_Handler,                          /*  90  GPIO 1 individual interrupt 2 */
  GPIO1_3_Handler,                          /*  91  GPIO 1 individual interrupt 3 */
  GPIO1_4_Handler,                          /*  92  GPIO 1 individual interrupt 4 */
  GPIO1_5_Handler,                          /*  93  GPIO 1 individual interrupt 5 */
  GPIO1_6_Handler,                          /*  94  GPIO 1 individual interrupt 6 */
  GPIO1_7_Handler,                          /*  95  GPIO 1 individual interrupt 7 */
  GPIO1_8_Handler,                          /*  96  GPIO 1 individual interrupt 8 */
  GPIO1_9_Handler,                          /*  97  GPIO 1 individual interrupt 9 */
  GPIO1_10_Handler,                         /*  98  GPIO 1 individual interrupt 10 */
  GPIO1_11_Handler,                         /*  99  GPIO 1 individual interrupt 11 */
  GPIO1_12_Handler,                         /* 100  GPIO 1 individual interrupt 12 */
  GPIO1_13_Handler,                         /* 101  GPIO 1 individual interrupt 13 */
  GPIO1_14_Handler,                         /* 102  GPIO 1 individual interrupt 14 */
  GPIO1_15_Handler,                         /* 103  GPIO 1 individual interrupt 15 */
  GPIO2_0_Handler,                          /* 104  GPIO 2 individual interrupt 0 */
  GPIO2_1_Handler,                          /* 105  GPIO 2 individual interrupt 1 */
  GPIO2_2_Handler,                          /* 106  GPIO 2 individual interrupt 2 */
  GPIO2_3_Handler,                          /* 107  GPIO 2 individual interrupt 3 */
  GPIO2_4_Handler,                          /* 108  GPIO 2 individual interrupt 4 */
  GPIO2_5_Handler,                          /* 109  GPIO 2 individual interrupt 5 */
  GPIO2_6_Handler,                          /* 110  GPIO 2 individual interrupt 6 */
  GPIO2_7_Handler,                          /* 111  GPIO 2 individual interrupt 7 */
  GPIO2_8_Handler,                          /* 112  GPIO 2 individual interrupt 8 */
  GPIO2_9_Handler,                          /* 113  GPIO 2 individual interrupt 9 */
  GPIO2_10_Handler,                         /* 114  GPIO 2 individual interrupt 10 */
  GPIO2_11_Handler,                         /* 115  GPIO 2 individual interrupt 11 */
  GPIO2_12_Handler,                         /* 116  GPIO 2 individual interrupt 12 */
  GPIO2_13_Handler,                         /* 117  GPIO 2 individual interrupt 13 */
  GPIO2_14_Handler,                         /* 118  GPIO 2 individual interrupt 14 */
  GPIO2_15_Handler,                         /* 119  GPIO 2 individual interrupt 15 */
  GPIO3_0_Handler,                          /* 120  GPIO 3 individual interrupt 0 */
  GPIO3_1_Handler,                          /* 121  GPIO 3 individual interrupt 1 */
  GPIO3_2_Handler,                          /* 122  GPIO 3 individual interrupt 2 */
  GPIO3_3_Handler,                          /* 123  GPIO 3 individual interrupt 3 */
  UART5RX_Handler,                          /* 124  UART 5 Receive Interrupt */
  UART5TX_Handler,                          /* 125  UART 5 Transmit Interrupt */
  UART5_Handler                             /* 126  UART 5 Combined Interrupt */
};


/*----------------------------------------------------------------------------
  Reset Handler called on controller reset
 *----------------------------------------------------------------------------*/
void Reset_Handler(void) {
  uint32_t *pSrc, *pDest;
  uint32_t *pTable __attribute__((unused));

/*  Firstly it copies data from read only memory to RAM. There are two schemes
 *  to copy. One can copy more than one sections. Another can only copy
 *  one section.  The former scheme needs more instructions and read-only
 *  data to implement than the latter.
 *  Macro __STARTUP_COPY_MULTIPLE is used to choose between two schemes.  */

#ifdef __STARTUP_COPY_MULTIPLE
/*  Multiple sections scheme.
 *
 *  Between symbol address __copy_table_start__ and __copy_table_end__,
 *  there are array of triplets, each of which specify:
 *    offset 0: LMA of start of a section to copy from
 *    offset 4: VMA of start of a section to copy to
 *    offset 8: size of the section to copy. Must be multiply of 4
 *
 *  All addresses must be aligned to 4 bytes boundary.
 */
  pTable = &__copy_table_start__;

  for (; pTable < &__copy_table_end__; pTable = pTable + 3) {
		pSrc  = (uint32_t*)*(pTable + 0);
		pDest = (uint32_t*)*(pTable + 1);
		for (; pDest < (uint32_t*)(*(pTable + 1) + *(pTable + 2)) ; ) {
      *pDest++ = *pSrc++;
		}
	}
#else
/*  Single section scheme.
 *
 *  The ranges of copy from/to are specified by following symbols
 *    __etext: LMA of start of the section to copy from. Usually end of text
 *    __data_start__: VMA of start of the section to copy to
 *    __data_end__: VMA of end of the section to copy to
 *
 *  All addresses must be aligned to 4 bytes boundary.
 */
  pSrc  = &__etext;
  pDest = &__data_start__;

  for ( ; pDest < &__data_end__ ; ) {
    *pDest++ = *pSrc++;
  }
#endif /*__STARTUP_COPY_MULTIPLE */

/*  This part of work usually is done in C library startup code. Otherwise,
 *  define this macro to enable it in this startup.
 *
 *  There are two schemes too. One can clear multiple BSS sections. Another
 *  can only clear one section. The former is more size expensive than the
 *  latter.
 *
 *  Define macro __STARTUP_CLEAR_BSS_MULTIPLE to choose the former.
 *  Otherwise efine macro __STARTUP_CLEAR_BSS to choose the later.
 */
#ifdef __STARTUP_CLEAR_BSS_MULTIPLE
/*  Multiple sections scheme.
 *
 *  Between symbol address __copy_table_start__ and __copy_table_end__,
 *  there are array of tuples specifying:
 *    offset 0: Start of a BSS section
 *    offset 4: Size of this BSS section. Must be multiply of 4
 */
  pTable = &__zero_table_start__;

  for (; pTable < &__zero_table_end__; pTable = pTable + 2) {
		pDest = (uint32_t*)*(pTable + 0);
		for (; pDest < (uint32_t*)(*(pTable + 0) + *(pTable + 1)) ; ) {
      *pDest++ = 0;
		}
	}
#elif defined (__STARTUP_CLEAR_BSS)
/*  Single BSS section scheme.
 *
 *  The BSS section is specified by following symbols
 *    __bss_start__: start of the BSS section.
 *    __bss_end__: end of the BSS section.
 *
 *  Both addresses must be aligned to 4 bytes boundary.
 */
  pDest = &__bss_start__;

  for ( ; pDest < &__bss_end__ ; ) {
    *pDest++ = 0ul;
  }
#endif /* __STARTUP_CLEAR_BSS_MULTIPLE || __STARTUP_CLEAR_BSS */

#ifndef __NO_SYSTEM_INIT
	SystemInit();
#endif

#ifndef __START
#define __START _start
#endif
	__START();

}


/*----------------------------------------------------------------------------
  Default Handler for Exceptions / Interrupts
 *----------------------------------------------------------------------------*/
void Default_Handler(void) {

	while(1);
}
